Class: Google::Apis::RedisV1::BackupConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Configuration for automatic backups

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupConfiguration

Returns a new instance of BackupConfiguration.



505
506
507
# File 'lib/google/apis/redis_v1/classes.rb', line 505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_enabledBoolean Also known as: automated_backup_enabled?

Whether customer visible automated backups are enabled on the instance. Corresponds to the JSON property automatedBackupEnabled

Returns:

  • (Boolean)


489
490
491
# File 'lib/google/apis/redis_v1/classes.rb', line 489

def automated_backup_enabled
  @automated_backup_enabled
end

#backup_retention_settingsGoogle::Apis::RedisV1::RetentionSettings

Backup retention settings. Corresponds to the JSON property backupRetentionSettings



495
496
497
# File 'lib/google/apis/redis_v1/classes.rb', line 495

def backup_retention_settings
  @backup_retention_settings
end

#point_in_time_recovery_enabledBoolean Also known as: point_in_time_recovery_enabled?

Whether point-in-time recovery is enabled. This is optional field, if the database service does not have this feature or metadata is not available in control plane, this can be omitted. Corresponds to the JSON property pointInTimeRecoveryEnabled

Returns:

  • (Boolean)


502
503
504
# File 'lib/google/apis/redis_v1/classes.rb', line 502

def point_in_time_recovery_enabled
  @point_in_time_recovery_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



510
511
512
513
514
# File 'lib/google/apis/redis_v1/classes.rb', line 510

def update!(**args)
  @automated_backup_enabled = args[:automated_backup_enabled] if args.key?(:automated_backup_enabled)
  @backup_retention_settings = args[:backup_retention_settings] if args.key?(:backup_retention_settings)
  @point_in_time_recovery_enabled = args[:point_in_time_recovery_enabled] if args.key?(:point_in_time_recovery_enabled)
end