Class: Google::Apis::RedisV1::Cluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

A cluster instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cluster

Returns a new instance of Cluster.



965
966
967
# File 'lib/google/apis/redis_v1/classes.rb', line 965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_policyString

Optional. The ACL policy to be applied to the cluster. Corresponds to the JSON property aclPolicy

Returns:

  • (String)


710
711
712
# File 'lib/google/apis/redis_v1/classes.rb', line 710

def acl_policy
  @acl_policy
end

#acl_policy_in_syncBoolean Also known as: acl_policy_in_sync?

Optional. Output only. Deprecated: Indicates whether the ACL rules applied to the cluster are in sync. Corresponds to the JSON property aclPolicyInSync

Returns:

  • (Boolean)


716
717
718
# File 'lib/google/apis/redis_v1/classes.rb', line 716

def acl_policy_in_sync
  @acl_policy_in_sync
end

#allow_fewer_zones_deploymentBoolean Also known as: allow_fewer_zones_deployment?

Optional. Immutable. Deprecated, do not use. Corresponds to the JSON property allowFewerZonesDeployment

Returns:

  • (Boolean)


722
723
724
# File 'lib/google/apis/redis_v1/classes.rb', line 722

def allow_fewer_zones_deployment
  @allow_fewer_zones_deployment
end

#async_cluster_endpoints_deletion_enabledBoolean Also known as: async_cluster_endpoints_deletion_enabled?

Optional. If true, cluster endpoints that are created and registered by customers can be deleted asynchronously. That is, such a cluster endpoint can be de-registered before the forwarding rules in the cluster endpoint are deleted. Corresponds to the JSON property asyncClusterEndpointsDeletionEnabled

Returns:

  • (Boolean)


731
732
733
# File 'lib/google/apis/redis_v1/classes.rb', line 731

def async_cluster_endpoints_deletion_enabled
  @async_cluster_endpoints_deletion_enabled
end

#authorization_modeString

Optional. The authorization mode of the Redis cluster. If not provided, auth feature is disabled for the cluster. Corresponds to the JSON property authorizationMode

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/redis_v1/classes.rb', line 738

def authorization_mode
  @authorization_mode
end

#automated_backup_configGoogle::Apis::RedisV1::AutomatedBackupConfig

The automated backup config for a cluster. Corresponds to the JSON property automatedBackupConfig



743
744
745
# File 'lib/google/apis/redis_v1/classes.rb', line 743

def automated_backup_config
  @automated_backup_config
end

#available_maintenance_versionsArray<String>

Output only. This field is used to determine the available maintenance versions for the self service update. Corresponds to the JSON property availableMaintenanceVersions

Returns:

  • (Array<String>)


749
750
751
# File 'lib/google/apis/redis_v1/classes.rb', line 749

def available_maintenance_versions
  @available_maintenance_versions
end

#backup_collectionString

Optional. Output only. The backup collection full resource name. Example: projects/project/locations/location/backupCollections/collection Corresponds to the JSON property backupCollection

Returns:

  • (String)


755
756
757
# File 'lib/google/apis/redis_v1/classes.rb', line 755

def backup_collection
  @backup_collection
end

#cluster_endpointsArray<Google::Apis::RedisV1::ClusterEndpoint>

Optional. A list of cluster endpoints. Corresponds to the JSON property clusterEndpoints



760
761
762
# File 'lib/google/apis/redis_v1/classes.rb', line 760

def cluster_endpoints
  @cluster_endpoints
end

#create_timeString

Output only. The timestamp associated with the cluster creation request. Corresponds to the JSON property createTime

Returns:

  • (String)


765
766
767
# File 'lib/google/apis/redis_v1/classes.rb', line 765

def create_time
  @create_time
end

#cross_cluster_replication_configGoogle::Apis::RedisV1::CrossClusterReplicationConfig

Cross cluster replication config. Corresponds to the JSON property crossClusterReplicationConfig



770
771
772
# File 'lib/google/apis/redis_v1/classes.rb', line 770

def cross_cluster_replication_config
  @cross_cluster_replication_config
end

#deletion_protection_enabledBoolean Also known as: deletion_protection_enabled?

Optional. The delete operation will fail when the value is set to true. Corresponds to the JSON property deletionProtectionEnabled

Returns:

  • (Boolean)


775
776
777
# File 'lib/google/apis/redis_v1/classes.rb', line 775

def deletion_protection_enabled
  @deletion_protection_enabled
end

#discovery_endpointsArray<Google::Apis::RedisV1::DiscoveryEndpoint>

Output only. Endpoints created on each given network, for Redis clients to connect to the cluster. Currently only one discovery endpoint is supported. Corresponds to the JSON property discoveryEndpoints



782
783
784
# File 'lib/google/apis/redis_v1/classes.rb', line 782

def discovery_endpoints
  @discovery_endpoints
end

#effective_maintenance_versionString

Output only. This field represents the actual maintenance version of the cluster. Corresponds to the JSON property effectiveMaintenanceVersion

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/redis_v1/classes.rb', line 788

def effective_maintenance_version
  @effective_maintenance_version
end

#encryption_infoGoogle::Apis::RedisV1::EncryptionInfo

EncryptionInfo describes the encryption information of a cluster or a backup. Corresponds to the JSON property encryptionInfo



793
794
795
# File 'lib/google/apis/redis_v1/classes.rb', line 793

def encryption_info
  @encryption_info
end

#gcs_sourceGoogle::Apis::RedisV1::GcsBackupSource

Backups stored in Cloud Storage buckets. The Cloud Storage buckets need to be the same region as the clusters. Corresponds to the JSON property gcsSource



799
800
801
# File 'lib/google/apis/redis_v1/classes.rb', line 799

def gcs_source
  @gcs_source
end

#kms_keyString

Optional. The KMS key used to encrypt the at-rest data of the cluster. Corresponds to the JSON property kmsKey

Returns:

  • (String)


804
805
806
# File 'lib/google/apis/redis_v1/classes.rb', line 804

def kms_key
  @kms_key
end

#labelsHash<String,String>

Optional. Labels to represent user-provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


809
810
811
# File 'lib/google/apis/redis_v1/classes.rb', line 809

def labels
  @labels
end

#maintenance_policyGoogle::Apis::RedisV1::ClusterMaintenancePolicy

Maintenance policy per cluster. Corresponds to the JSON property maintenancePolicy



814
815
816
# File 'lib/google/apis/redis_v1/classes.rb', line 814

def maintenance_policy
  @maintenance_policy
end

#maintenance_scheduleGoogle::Apis::RedisV1::ClusterMaintenanceSchedule

Upcoming maintenance schedule. Corresponds to the JSON property maintenanceSchedule



819
820
821
# File 'lib/google/apis/redis_v1/classes.rb', line 819

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_versionString

Optional. This field can be used to trigger self service update to indicate the desired maintenance version. The input to this field can be determined by the available_maintenance_versions field. Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


826
827
828
# File 'lib/google/apis/redis_v1/classes.rb', line 826

def maintenance_version
  @maintenance_version
end

#managed_backup_sourceGoogle::Apis::RedisV1::ManagedBackupSource

Backups that generated and managed by memorystore. Corresponds to the JSON property managedBackupSource



831
832
833
# File 'lib/google/apis/redis_v1/classes.rb', line 831

def managed_backup_source
  @managed_backup_source
end

#nameString

Required. Identifier. Unique name of the resource in this scope including project and location using the form: projects/project_id/locations/ location_id/clusters/cluster_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


838
839
840
# File 'lib/google/apis/redis_v1/classes.rb', line 838

def name
  @name
end

#node_typeString

Optional. The type of a redis node in the cluster. NodeType determines the underlying machine-type of a redis node. Corresponds to the JSON property nodeType

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/redis_v1/classes.rb', line 844

def node_type
  @node_type
end

#ondemand_maintenanceBoolean Also known as: ondemand_maintenance?

Optional. Input only. Ondemand maintenance for the cluster. This field can be used to trigger ondemand critical update on the cluster. Corresponds to the JSON property ondemandMaintenance

Returns:

  • (Boolean)


850
851
852
# File 'lib/google/apis/redis_v1/classes.rb', line 850

def ondemand_maintenance
  @ondemand_maintenance
end

#persistence_configGoogle::Apis::RedisV1::ClusterPersistenceConfig

Configuration of the persistence functionality. Corresponds to the JSON property persistenceConfig



856
857
858
# File 'lib/google/apis/redis_v1/classes.rb', line 856

def persistence_config
  @persistence_config
end

#precise_size_gbFloat

Output only. Precise value of redis memory size in GB for the entire cluster. Corresponds to the JSON property preciseSizeGb

Returns:

  • (Float)


861
862
863
# File 'lib/google/apis/redis_v1/classes.rb', line 861

def precise_size_gb
  @precise_size_gb
end

#psc_configsArray<Google::Apis::RedisV1::PscConfig>

Optional. Each PscConfig configures the consumer network where IPs will be designated to the cluster for client access through Private Service Connect Automation. Currently, only one PscConfig is supported. Corresponds to the JSON property pscConfigs



868
869
870
# File 'lib/google/apis/redis_v1/classes.rb', line 868

def psc_configs
  @psc_configs
end

#psc_connectionsArray<Google::Apis::RedisV1::PscConnection>

Output only. The list of PSC connections that are auto-created through service connectivity automation. Corresponds to the JSON property pscConnections



874
875
876
# File 'lib/google/apis/redis_v1/classes.rb', line 874

def psc_connections
  @psc_connections
end

#psc_service_attachmentsArray<Google::Apis::RedisV1::PscServiceAttachment>

Output only. Service attachment details to configure Psc connections Corresponds to the JSON property pscServiceAttachments



879
880
881
# File 'lib/google/apis/redis_v1/classes.rb', line 879

def psc_service_attachments
  @psc_service_attachments
end

#redis_configsHash<String,String>

Optional. Key/Value pairs of customer overrides for mutable Redis Configs Corresponds to the JSON property redisConfigs

Returns:

  • (Hash<String,String>)


884
885
886
# File 'lib/google/apis/redis_v1/classes.rb', line 884

def redis_configs
  @redis_configs
end

#replica_countFixnum

Optional. The number of replica nodes per shard. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


889
890
891
# File 'lib/google/apis/redis_v1/classes.rb', line 889

def replica_count
  @replica_count
end

#rotate_server_certificateBoolean Also known as: rotate_server_certificate?

Optional. Input only. Rotate the server certificates. Corresponds to the JSON property rotateServerCertificate

Returns:

  • (Boolean)


894
895
896
# File 'lib/google/apis/redis_v1/classes.rb', line 894

def rotate_server_certificate
  @rotate_server_certificate
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


900
901
902
# File 'lib/google/apis/redis_v1/classes.rb', line 900

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


906
907
908
# File 'lib/google/apis/redis_v1/classes.rb', line 906

def satisfies_pzs
  @satisfies_pzs
end

#server_ca_modeString

Optional. Server CA mode for the cluster. Corresponds to the JSON property serverCaMode

Returns:

  • (String)


912
913
914
# File 'lib/google/apis/redis_v1/classes.rb', line 912

def server_ca_mode
  @server_ca_mode
end

#server_ca_poolString

Optional. Customer-managed CA pool for the cluster. Only applicable for BYOCA i.e. if server_ca_mode is SERVER_CA_MODE_CUSTOMER_MANAGED_CAS_CA. Format: " projects/project/locations/region/caPools/ca_pool". Corresponds to the JSON property serverCaPool

Returns:

  • (String)


919
920
921
# File 'lib/google/apis/redis_v1/classes.rb', line 919

def server_ca_pool
  @server_ca_pool
end

#shard_countFixnum

Optional. Number of shards for the Redis cluster. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


924
925
926
# File 'lib/google/apis/redis_v1/classes.rb', line 924

def shard_count
  @shard_count
end

#simulate_maintenance_eventBoolean Also known as: simulate_maintenance_event?

Optional. Input only. Simulate a maintenance event. Corresponds to the JSON property simulateMaintenanceEvent

Returns:

  • (Boolean)


929
930
931
# File 'lib/google/apis/redis_v1/classes.rb', line 929

def simulate_maintenance_event
  @simulate_maintenance_event
end

#size_gbFixnum

Output only. Redis memory size in GB for the entire cluster rounded up to the next integer. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


936
937
938
# File 'lib/google/apis/redis_v1/classes.rb', line 936

def size_gb
  @size_gb
end

#stateString

Output only. The current state of this cluster. Can be CREATING, READY, UPDATING, DELETING and SUSPENDED Corresponds to the JSON property state

Returns:

  • (String)


942
943
944
# File 'lib/google/apis/redis_v1/classes.rb', line 942

def state
  @state
end

#state_infoGoogle::Apis::RedisV1::StateInfo

Represents additional information about the state of the cluster. Corresponds to the JSON property stateInfo



947
948
949
# File 'lib/google/apis/redis_v1/classes.rb', line 947

def state_info
  @state_info
end

#transit_encryption_modeString

Optional. The in-transit encryption for the Redis cluster. If not provided, encryption is disabled for the cluster. Corresponds to the JSON property transitEncryptionMode

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/redis_v1/classes.rb', line 953

def transit_encryption_mode
  @transit_encryption_mode
end

#uidString

Output only. System assigned, unique identifier for the cluster. Corresponds to the JSON property uid

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/redis_v1/classes.rb', line 958

def uid
  @uid
end

#zone_distribution_configGoogle::Apis::RedisV1::ZoneDistributionConfig

Zone distribution config for allocation of cluster resources. Corresponds to the JSON property zoneDistributionConfig



963
964
965
# File 'lib/google/apis/redis_v1/classes.rb', line 963

def zone_distribution_config
  @zone_distribution_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
# File 'lib/google/apis/redis_v1/classes.rb', line 970

def update!(**args)
  @acl_policy = args[:acl_policy] if args.key?(:acl_policy)
  @acl_policy_in_sync = args[:acl_policy_in_sync] if args.key?(:acl_policy_in_sync)
  @allow_fewer_zones_deployment = args[:allow_fewer_zones_deployment] if args.key?(:allow_fewer_zones_deployment)
  @async_cluster_endpoints_deletion_enabled = args[:async_cluster_endpoints_deletion_enabled] if args.key?(:async_cluster_endpoints_deletion_enabled)
  @authorization_mode = args[:authorization_mode] if args.key?(:authorization_mode)
  @automated_backup_config = args[:automated_backup_config] if args.key?(:automated_backup_config)
  @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions)
  @backup_collection = args[:backup_collection] if args.key?(:backup_collection)
  @cluster_endpoints = args[:cluster_endpoints] if args.key?(:cluster_endpoints)
  @create_time = args[:create_time] if args.key?(:create_time)
  @cross_cluster_replication_config = args[:cross_cluster_replication_config] if args.key?(:cross_cluster_replication_config)
  @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled)
  @discovery_endpoints = args[:discovery_endpoints] if args.key?(:discovery_endpoints)
  @effective_maintenance_version = args[:effective_maintenance_version] if args.key?(:effective_maintenance_version)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @managed_backup_source = args[:managed_backup_source] if args.key?(:managed_backup_source)
  @name = args[:name] if args.key?(:name)
  @node_type = args[:node_type] if args.key?(:node_type)
  @ondemand_maintenance = args[:ondemand_maintenance] if args.key?(:ondemand_maintenance)
  @persistence_config = args[:persistence_config] if args.key?(:persistence_config)
  @precise_size_gb = args[:precise_size_gb] if args.key?(:precise_size_gb)
  @psc_configs = args[:psc_configs] if args.key?(:psc_configs)
  @psc_connections = args[:psc_connections] if args.key?(:psc_connections)
  @psc_service_attachments = args[:psc_service_attachments] if args.key?(:psc_service_attachments)
  @redis_configs = args[:redis_configs] if args.key?(:redis_configs)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @rotate_server_certificate = args[:rotate_server_certificate] if args.key?(:rotate_server_certificate)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @server_ca_mode = args[:server_ca_mode] if args.key?(:server_ca_mode)
  @server_ca_pool = args[:server_ca_pool] if args.key?(:server_ca_pool)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @simulate_maintenance_event = args[:simulate_maintenance_event] if args.key?(:simulate_maintenance_event)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @state = args[:state] if args.key?(:state)
  @state_info = args[:state_info] if args.key?(:state_info)
  @transit_encryption_mode = args[:transit_encryption_mode] if args.key?(:transit_encryption_mode)
  @uid = args[:uid] if args.key?(:uid)
  @zone_distribution_config = args[:zone_distribution_config] if args.key?(:zone_distribution_config)
end