Class: Google::Apis::RedisV1::ClusterEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

ClusterEndpoint consists of PSC connections that are created as a group in each VPC network for accessing the cluster. In each group, there shall be one connection for each service attachment in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterEndpoint

Returns a new instance of ClusterEndpoint.



1031
1032
1033
# File 'lib/google/apis/redis_v1/classes.rb', line 1031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsArray<Google::Apis::RedisV1::ConnectionDetail>

Required. A group of PSC connections. They are created in the same VPC network, one for each service attachment in the cluster. Corresponds to the JSON property connections



1029
1030
1031
# File 'lib/google/apis/redis_v1/classes.rb', line 1029

def connections
  @connections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1036
1037
1038
# File 'lib/google/apis/redis_v1/classes.rb', line 1036

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
end