Class: Google::Apis::RedisV1::ClusterMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Upcoming maintenance schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterMaintenanceSchedule

Returns a new instance of ClusterMaintenanceSchedule.



1093
1094
1095
# File 'lib/google/apis/redis_v1/classes.rb', line 1093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The end time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property endTime

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/redis_v1/classes.rb', line 1085

def end_time
  @end_time
end

#start_timeString

Output only. The start time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property startTime

Returns:

  • (String)


1091
1092
1093
# File 'lib/google/apis/redis_v1/classes.rb', line 1091

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1098
1099
1100
1101
# File 'lib/google/apis/redis_v1/classes.rb', line 1098

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end