Class: Google::Apis::RedisV1::ConfigBasedSignalData
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ConfigBasedSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Signal data for boolean signals.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigBasedSignalData
constructor
A new instance of ConfigBasedSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigBasedSignalData
Returns a new instance of ConfigBasedSignalData.
1219 1220 1221 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
1196 1197 1198 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1196 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
1201 1202 1203 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1201 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
1206 1207 1208 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1206 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Signal data for boolean signals.
Corresponds to the JSON property signalBoolValue
1211 1212 1213 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1211 def signal_bool_value @signal_bool_value end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
1217 1218 1219 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1217 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1224 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_type = args[:signal_type] if args.key?(:signal_type) end |