Class: Google::Apis::RedisV1::DatabaseResourceFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceFeed

Returns a new instance of DatabaseResourceFeed.



1397
1398
1399
# File 'lib/google/apis/redis_v1/classes.rb', line 1397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupdr_metadataGoogle::Apis::RedisV1::BackupDrMetadata

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource. Corresponds to the JSON property backupdrMetadata



1336
1337
1338
# File 'lib/google/apis/redis_v1/classes.rb', line 1336

def 
  @backupdr_metadata
end

#config_based_signal_dataGoogle::Apis::RedisV1::ConfigBasedSignalData

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases. Corresponds to the JSON property configBasedSignalData



1343
1344
1345
# File 'lib/google/apis/redis_v1/classes.rb', line 1343

def config_based_signal_data
  @config_based_signal_data
end

#database_resource_signal_dataGoogle::Apis::RedisV1::DatabaseResourceSignalData

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10 Corresponds to the JSON property databaseResourceSignalData



1350
1351
1352
# File 'lib/google/apis/redis_v1/classes.rb', line 1350

def database_resource_signal_data
  @database_resource_signal_data
end

#feed_timestampString

Required. Timestamp when feed is generated. Corresponds to the JSON property feedTimestamp

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/redis_v1/classes.rb', line 1355

def feed_timestamp
  @feed_timestamp
end

#feed_typeString

Required. Type feed to be ingested into condor Corresponds to the JSON property feedType

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/redis_v1/classes.rb', line 1360

def feed_type
  @feed_type
end

#observability_metric_dataGoogle::Apis::RedisV1::ObservabilityMetricData

Observability metric data. Corresponds to the JSON property observabilityMetricData



1365
1366
1367
# File 'lib/google/apis/redis_v1/classes.rb', line 1365

def observability_metric_data
  @observability_metric_data
end

#recommendation_signal_dataGoogle::Apis::RedisV1::DatabaseResourceRecommendationSignalData

Common model for database resource recommendation signal data. Corresponds to the JSON property recommendationSignalData



1370
1371
1372
# File 'lib/google/apis/redis_v1/classes.rb', line 1370

def recommendation_signal_data
  @recommendation_signal_data
end

#resource_health_signal_dataGoogle::Apis::RedisV1::DatabaseResourceHealthSignalData

Common model for database resource health signal data. Corresponds to the JSON property resourceHealthSignalData



1375
1376
1377
# File 'lib/google/apis/redis_v1/classes.rb', line 1375

def resource_health_signal_data
  @resource_health_signal_data
end

#resource_idGoogle::Apis::RedisV1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



1380
1381
1382
# File 'lib/google/apis/redis_v1/classes.rb', line 1380

def resource_id
  @resource_id
end

#resource_metadataGoogle::Apis::RedisV1::DatabaseResourceMetadata

Common model for database resource instance metadata. Next ID: 35 Corresponds to the JSON property resourceMetadata



1385
1386
1387
# File 'lib/google/apis/redis_v1/classes.rb', line 1385

def 
  @resource_metadata
end

#skip_ingestionBoolean Also known as: skip_ingestion?

Optional. If true, the feed won't be ingested by DB Center. This indicates that the feed is intentionally skipped. For example, BackupDR feeds are only needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB). Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can be skipped. Corresponds to the JSON property skipIngestion

Returns:

  • (Boolean)


1394
1395
1396
# File 'lib/google/apis/redis_v1/classes.rb', line 1394

def skip_ingestion
  @skip_ingestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/google/apis/redis_v1/classes.rb', line 1402

def update!(**args)
  @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata)
  @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data)
  @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data)
  @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp)
  @feed_type = args[:feed_type] if args.key?(:feed_type)
  @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data)
  @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data)
  @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata)
  @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion)
end