Class: Google::Apis::RedisV1::DatabaseResourceId
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::DatabaseResourceId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
DatabaseResourceId will serve as primary key for any resource ingestion event.
Instance Attribute Summary collapse
-
#provider ⇒ String
Required.
-
#provider_description ⇒ String
Optional.
-
#resource_type ⇒ String
Required.
-
#unique_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceId
constructor
A new instance of DatabaseResourceId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceId
Returns a new instance of DatabaseResourceId.
1568 1569 1570 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#provider ⇒ String
Required. Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged
Corresponds to the JSON property provider
1542 1543 1544 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1542 def provider @provider end |
#provider_description ⇒ String
Optional. Needs to be used only when the provider is PROVIDER_OTHER.
Corresponds to the JSON property providerDescription
1547 1548 1549 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1547 def provider_description @provider_description end |
#resource_type ⇒ String
Required. The type of resource this ID is identifying. Ex go/keep-sorted start
alloydb.googleapis.com/Cluster, alloydb.googleapis.com/Instance, bigtableadmin.
googleapis.com/Cluster, bigtableadmin.googleapis.com/Instance compute.
googleapis.com/Instance firestore.googleapis.com/Database, redis.googleapis.
com/Instance, redis.googleapis.com/Cluster, oracledatabase.googleapis.com/
CloudExadataInfrastructure oracledatabase.googleapis.com/CloudVmCluster
oracledatabase.googleapis.com/AutonomousDatabase spanner.googleapis.com/
Instance, spanner.googleapis.com/Database, sqladmin.googleapis.com/Instance,
go/keep-sorted end REQUIRED Please refer go/condor-common-datamodel
Corresponds to the JSON property resourceType
1560 1561 1562 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1560 def resource_type @resource_type end |
#unique_id ⇒ String
Required. A service-local token that distinguishes this resource from other
resources within the same service.
Corresponds to the JSON property uniqueId
1566 1567 1568 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1566 def unique_id @unique_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1573 1574 1575 1576 1577 1578 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1573 def update!(**args) @provider = args[:provider] if args.key?(:provider) @provider_description = args[:provider_description] if args.key?(:provider_description) @resource_type = args[:resource_type] if args.key?(:resource_type) @unique_id = args[:unique_id] if args.key?(:unique_id) end |