Class: Google::Apis::RedisV1::DatabaseResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Common model for database resource instance metadata. Next ID: 35

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceMetadata

Returns a new instance of DatabaseResourceMetadata.



1766
1767
1768
# File 'lib/google/apis/redis_v1/classes.rb', line 1766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_metadataHash<String,Object>

Field to ingest additional metadata whichd does not support proto format. Corresponds to the JSON property additionalMetadata

Returns:

  • (Hash<String,Object>)


1587
1588
1589
# File 'lib/google/apis/redis_v1/classes.rb', line 1587

def 
  @additional_metadata
end

#availability_configurationGoogle::Apis::RedisV1::AvailabilityConfiguration

Configuration for availability of database instance Corresponds to the JSON property availabilityConfiguration



1592
1593
1594
# File 'lib/google/apis/redis_v1/classes.rb', line 1592

def availability_configuration
  @availability_configuration
end

#backup_configurationGoogle::Apis::RedisV1::BackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



1597
1598
1599
# File 'lib/google/apis/redis_v1/classes.rb', line 1597

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::RedisV1::BackupRun

A backup run. Corresponds to the JSON property backupRun



1602
1603
1604
# File 'lib/google/apis/redis_v1/classes.rb', line 1602

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::RedisV1::BackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



1608
1609
1610
# File 'lib/google/apis/redis_v1/classes.rb', line 1608

def backupdr_configuration
  @backupdr_configuration
end

#creation_timeString

The creation time of the resource, i.e. the time when resource is created and recorded in partner service. Corresponds to the JSON property creationTime

Returns:

  • (String)


1614
1615
1616
# File 'lib/google/apis/redis_v1/classes.rb', line 1614

def creation_time
  @creation_time
end

#current_stateString

Current state of the instance. Corresponds to the JSON property currentState

Returns:

  • (String)


1619
1620
1621
# File 'lib/google/apis/redis_v1/classes.rb', line 1619

def current_state
  @current_state
end

#custom_metadataGoogle::Apis::RedisV1::CustomMetadataData

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data Corresponds to the JSON property customMetadata



1626
1627
1628
# File 'lib/google/apis/redis_v1/classes.rb', line 1626

def 
  @custom_metadata
end

#editionString

Optional. Edition represents whether the instance is ENTERPRISE or ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to identify the edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/redis_v1/classes.rb', line 1633

def edition
  @edition
end

#entitlementsArray<Google::Apis::RedisV1::Entitlement>

Entitlements associated with the resource Corresponds to the JSON property entitlements



1638
1639
1640
# File 'lib/google/apis/redis_v1/classes.rb', line 1638

def entitlements
  @entitlements
end

#expected_stateString

The state that the instance is expected to be in. For example, an instance state can transition to UNHEALTHY due to wrong patch update, while the expected state will remain at the HEALTHY. Corresponds to the JSON property expectedState

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/redis_v1/classes.rb', line 1645

def expected_state
  @expected_state
end

#gcbdr_configurationGoogle::Apis::RedisV1::GcbdrConfiguration

GCBDR Configuration for the resource. Corresponds to the JSON property gcbdrConfiguration



1650
1651
1652
# File 'lib/google/apis/redis_v1/classes.rb', line 1650

def gcbdr_configuration
  @gcbdr_configuration
end

#idGoogle::Apis::RedisV1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property id



1655
1656
1657
# File 'lib/google/apis/redis_v1/classes.rb', line 1655

def id
  @id
end

#instance_typeString

The type of the instance. Specified at creation time. Corresponds to the JSON property instanceType

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/redis_v1/classes.rb', line 1660

def instance_type
  @instance_type
end

#internal_additional_metadataHash<String,Object>

Field to ingest additional metadata which support proto format. Corresponds to the JSON property internalAdditionalMetadata

Returns:

  • (Hash<String,Object>)


1665
1666
1667
# File 'lib/google/apis/redis_v1/classes.rb', line 1665

def 
  @internal_additional_metadata
end

#ip_addressGoogle::Apis::RedisV1::IpAddress

Used to send IP address information for a database resource. Corresponds to the JSON property ipAddress



1670
1671
1672
# File 'lib/google/apis/redis_v1/classes.rb', line 1670

def ip_address
  @ip_address
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Optional. Whether deletion protection is enabled for this resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


1675
1676
1677
# File 'lib/google/apis/redis_v1/classes.rb', line 1675

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#locationString

The resource location. REQUIRED Corresponds to the JSON property location

Returns:

  • (String)


1681
1682
1683
# File 'lib/google/apis/redis_v1/classes.rb', line 1681

def location
  @location
end

#machine_configurationGoogle::Apis::RedisV1::MachineConfiguration

MachineConfiguration describes the configuration of a machine specific to Database Resource. Corresponds to the JSON property machineConfiguration



1687
1688
1689
# File 'lib/google/apis/redis_v1/classes.rb', line 1687

def machine_configuration
  @machine_configuration
end

#maintenance_infoGoogle::Apis::RedisV1::ResourceMaintenanceInfo

MaintenanceInfo to capture the maintenance details of database resource. Corresponds to the JSON property maintenanceInfo



1692
1693
1694
# File 'lib/google/apis/redis_v1/classes.rb', line 1692

def maintenance_info
  @maintenance_info
end

#modesArray<String>

Optional. The modes of the database resource. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


1697
1698
1699
# File 'lib/google/apis/redis_v1/classes.rb', line 1697

def modes
  @modes
end

#primary_resource_idGoogle::Apis::RedisV1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property primaryResourceId



1702
1703
1704
# File 'lib/google/apis/redis_v1/classes.rb', line 1702

def primary_resource_id
  @primary_resource_id
end

#primary_resource_locationString

Primary resource location. REQUIRED if the immediate parent exists when first time resource is getting ingested, otherwise optional. Corresponds to the JSON property primaryResourceLocation

Returns:

  • (String)


1708
1709
1710
# File 'lib/google/apis/redis_v1/classes.rb', line 1708

def primary_resource_location
  @primary_resource_location
end

#productGoogle::Apis::RedisV1::Product

Product specification for Condor resources. Corresponds to the JSON property product



1713
1714
1715
# File 'lib/google/apis/redis_v1/classes.rb', line 1713

def product
  @product
end

#resource_containerString

Closest parent Cloud Resource Manager container of this resource. It must be resource name of a Cloud Resource Manager project with the format of "/", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1720
1721
1722
# File 'lib/google/apis/redis_v1/classes.rb', line 1720

def resource_container
  @resource_container
end

#resource_flagsArray<Google::Apis::RedisV1::ResourceFlags>

Optional. List of resource flags for the database resource. Corresponds to the JSON property resourceFlags



1725
1726
1727
# File 'lib/google/apis/redis_v1/classes.rb', line 1725

def resource_flags
  @resource_flags
end

#resource_nameString

Required. Different from DatabaseResourceId.unique_id, a resource name can be reused over time. That is, after a resource named "ABC" is deleted, the name " ABC" can be used to to create a new resource within the same source. Resource name to follow CAIS resource_name format as noted here go/condor-common- datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


1734
1735
1736
# File 'lib/google/apis/redis_v1/classes.rb', line 1734

def resource_name
  @resource_name
end

#suspension_reasonString

Optional. Suspension reason for the resource. Corresponds to the JSON property suspensionReason

Returns:

  • (String)


1739
1740
1741
# File 'lib/google/apis/redis_v1/classes.rb', line 1739

def suspension_reason
  @suspension_reason
end

#tags_setGoogle::Apis::RedisV1::Tags

Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag. Corresponds to the JSON property tagsSet



1746
1747
1748
# File 'lib/google/apis/redis_v1/classes.rb', line 1746

def tags_set
  @tags_set
end

#updation_timeString

The time at which the resource was updated and recorded at partner service. Corresponds to the JSON property updationTime

Returns:

  • (String)


1751
1752
1753
# File 'lib/google/apis/redis_v1/classes.rb', line 1751

def updation_time
  @updation_time
end

#user_label_setGoogle::Apis::RedisV1::UserLabels

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels. Corresponds to the JSON property userLabelSet



1758
1759
1760
# File 'lib/google/apis/redis_v1/classes.rb', line 1758

def user_label_set
  @user_label_set
end

#zoneString

The resource zone. This is only applicable for zonal resources and will be empty for regional and multi-regional resources. Corresponds to the JSON property zone

Returns:

  • (String)


1764
1765
1766
# File 'lib/google/apis/redis_v1/classes.rb', line 1764

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
# File 'lib/google/apis/redis_v1/classes.rb', line 1771

def update!(**args)
  @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata)
  @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @current_state = args[:current_state] if args.key?(:current_state)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @edition = args[:edition] if args.key?(:edition)
  @entitlements = args[:entitlements] if args.key?(:entitlements)
  @expected_state = args[:expected_state] if args.key?(:expected_state)
  @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration)
  @id = args[:id] if args.key?(:id)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @internal_additional_metadata = args[:internal_additional_metadata] if args.key?(:internal_additional_metadata)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @location = args[:location] if args.key?(:location)
  @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration)
  @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info)
  @modes = args[:modes] if args.key?(:modes)
  @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id)
  @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location)
  @product = args[:product] if args.key?(:product)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_flags = args[:resource_flags] if args.key?(:resource_flags)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @tags_set = args[:tags_set] if args.key?(:tags_set)
  @updation_time = args[:updation_time] if args.key?(:updation_time)
  @user_label_set = args[:user_label_set] if args.key?(:user_label_set)
  @zone = args[:zone] if args.key?(:zone)
end