Class: Google::Apis::RedisV1::FixedFrequencySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

This schedule allows the backup to be triggered at a fixed frequency ( currently only daily is supported).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixedFrequencySchedule

Returns a new instance of FixedFrequencySchedule.



2175
2176
2177
# File 'lib/google/apis/redis_v1/classes.rb', line 2175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#start_timeGoogle::Apis::RedisV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2173
2174
2175
# File 'lib/google/apis/redis_v1/classes.rb', line 2173

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2180
2181
2182
# File 'lib/google/apis/redis_v1/classes.rb', line 2180

def update!(**args)
  @start_time = args[:start_time] if args.key?(:start_time)
end