Class: Google::Apis::RedisV1::GoogleCloudRedisV1LocationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

This location metadata represents additional configuration options for a given location where a Redis instance may be created. All fields are output only. It is returned as content of the google.cloud.location.Location.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRedisV1LocationMetadata

Returns a new instance of GoogleCloudRedisV1LocationMetadata.



2262
2263
2264
# File 'lib/google/apis/redis_v1/classes.rb', line 2262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_zonesHash<String,Google::Apis::RedisV1::GoogleCloudRedisV1ZoneMetadata>

Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by GCE. These keys can be specified in location_id or alternative_location_id fields when creating a Redis instance. Corresponds to the JSON property availableZones



2260
2261
2262
# File 'lib/google/apis/redis_v1/classes.rb', line 2260

def available_zones
  @available_zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2267
2268
2269
# File 'lib/google/apis/redis_v1/classes.rb', line 2267

def update!(**args)
  @available_zones = args[:available_zones] if args.key?(:available_zones)
end