Class: Google::Apis::RedisV1::ListAuthTokensResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Response message for ListAuthTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAuthTokensResponse

Returns a new instance of ListAuthTokensResponse.



2856
2857
2858
# File 'lib/google/apis/redis_v1/classes.rb', line 2856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_tokensArray<Google::Apis::RedisV1::AuthToken>

A list of auth tokens in the project. Corresponds to the JSON property authTokens



2843
2844
2845
# File 'lib/google/apis/redis_v1/classes.rb', line 2843

def auth_tokens
  @auth_tokens
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/redis_v1/classes.rb', line 2849

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Auth tokens that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2854
2855
2856
# File 'lib/google/apis/redis_v1/classes.rb', line 2854

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2861
2862
2863
2864
2865
# File 'lib/google/apis/redis_v1/classes.rb', line 2861

def update!(**args)
  @auth_tokens = args[:auth_tokens] if args.key?(:auth_tokens)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end