Class: Google::Apis::RedisV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Response for ListBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



3137
3138
3139
# File 'lib/google/apis/redis_v1/classes.rb', line 3137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::RedisV1::Backup>

A list of backups in the project. Corresponds to the JSON property backups

Returns:



3124
3125
3126
# File 'lib/google/apis/redis_v1/classes.rb', line 3124

def backups
  @backups
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3130
3131
3132
# File 'lib/google/apis/redis_v1/classes.rb', line 3130

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Backups that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3135
3136
3137
# File 'lib/google/apis/redis_v1/classes.rb', line 3135

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3142
3143
3144
3145
3146
# File 'lib/google/apis/redis_v1/classes.rb', line 3142

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end