Class: Google::Apis::RedisV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



3063
3064
3065
# File 'lib/google/apis/redis_v1/classes.rb', line 3063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/redis_v1/classes.rb', line 3048

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::RedisV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



3053
3054
3055
# File 'lib/google/apis/redis_v1/classes.rb', line 3053

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3061
3062
3063
# File 'lib/google/apis/redis_v1/classes.rb', line 3061

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3068
3069
3070
3071
3072
# File 'lib/google/apis/redis_v1/classes.rb', line 3068

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end