Class: Google::Apis::RedisV1::ListTokenAuthUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Response message for ListTokenAuthUsers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTokenAuthUsersResponse

Returns a new instance of ListTokenAuthUsersResponse.



3096
3097
3098
# File 'lib/google/apis/redis_v1/classes.rb', line 3096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/redis_v1/classes.rb', line 3084

def next_page_token
  @next_page_token
end

#token_auth_usersArray<Google::Apis::RedisV1::TokenAuthUser>

A list of token auth users in the project. Corresponds to the JSON property tokenAuthUsers



3089
3090
3091
# File 'lib/google/apis/redis_v1/classes.rb', line 3089

def token_auth_users
  @token_auth_users
end

#unreachableArray<String>

Unordered list. Token auth users that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3094
3095
3096
# File 'lib/google/apis/redis_v1/classes.rb', line 3094

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3101
3102
3103
3104
3105
# File 'lib/google/apis/redis_v1/classes.rb', line 3101

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @token_auth_users = args[:token_auth_users] if args.key?(:token_auth_users)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end