Class: Google::Apis::RedisV1::MaintenancePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Maintenance policy for an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenancePolicy

Returns a new instance of MaintenancePolicy.



3238
3239
3240
# File 'lib/google/apis/redis_v1/classes.rb', line 3238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the policy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3218
3219
3220
# File 'lib/google/apis/redis_v1/classes.rb', line 3218

def create_time
  @create_time
end

#descriptionString

Optional. Description of what this policy is for. Create/Update methods return INVALID_ARGUMENT if the length is greater than 512. Corresponds to the JSON property description

Returns:

  • (String)


3224
3225
3226
# File 'lib/google/apis/redis_v1/classes.rb', line 3224

def description
  @description
end

#update_timeString

Output only. The time when the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3229
3230
3231
# File 'lib/google/apis/redis_v1/classes.rb', line 3229

def update_time
  @update_time
end

#weekly_maintenance_windowArray<Google::Apis::RedisV1::WeeklyMaintenanceWindow>

Optional. Maintenance window that is applied to resources covered by this policy. Minimum 1. For the current version, the maximum number of weekly_window is expected to be one. Corresponds to the JSON property weeklyMaintenanceWindow



3236
3237
3238
# File 'lib/google/apis/redis_v1/classes.rb', line 3236

def weekly_maintenance_window
  @weekly_maintenance_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3243
3244
3245
3246
3247
3248
# File 'lib/google/apis/redis_v1/classes.rb', line 3243

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @update_time = args[:update_time] if args.key?(:update_time)
  @weekly_maintenance_window = args[:weekly_maintenance_window] if args.key?(:weekly_maintenance_window)
end