Class: Google::Apis::RedisV1::Membership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

An output only view of all the member clusters participating in the cross cluster replication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



3019
3020
3021
# File 'lib/google/apis/redis_v1/classes.rb', line 3019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primary_clusterGoogle::Apis::RedisV1::RemoteCluster

Details of the remote cluster associated with this cluster in a cross cluster replication setup. Corresponds to the JSON property primaryCluster



3011
3012
3013
# File 'lib/google/apis/redis_v1/classes.rb', line 3011

def primary_cluster
  @primary_cluster
end

#secondary_clustersArray<Google::Apis::RedisV1::RemoteCluster>

Output only. The list of secondary clusters replicating from the primary cluster. Corresponds to the JSON property secondaryClusters



3017
3018
3019
# File 'lib/google/apis/redis_v1/classes.rb', line 3017

def secondary_clusters
  @secondary_clusters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3024
3025
3026
3027
# File 'lib/google/apis/redis_v1/classes.rb', line 3024

def update!(**args)
  @primary_cluster = args[:primary_cluster] if args.key?(:primary_cluster)
  @secondary_clusters = args[:secondary_clusters] if args.key?(:secondary_clusters)
end