Class: Google::Apis::RedisV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



3486
3487
3488
# File 'lib/google/apis/redis_v1/classes.rb', line 3486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


3443
3444
3445
# File 'lib/google/apis/redis_v1/classes.rb', line 3443

def done
  @done
end

#errorGoogle::Apis::RedisV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3454
3455
3456
# File 'lib/google/apis/redis_v1/classes.rb', line 3454

def error
  @error
end

#metadataHash<String,Object>

createTime: The time the operation was created.endTime: The time the operation finished running.target: Server-defined resource path for the target of the operation.verb: Name of the verb executed by the operation. statusDetail: Human-readable status of the operation, if any. cancelRequested: Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding toCode. CANCELLED.apiVersion: API version used to start the operation. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


3466
3467
3468
# File 'lib/google/apis/redis_v1/classes.rb', line 3466

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


3473
3474
3475
# File 'lib/google/apis/redis_v1/classes.rb', line 3473

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


3484
3485
3486
# File 'lib/google/apis/redis_v1/classes.rb', line 3484

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3491
3492
3493
3494
3495
3496
3497
# File 'lib/google/apis/redis_v1/classes.rb', line 3491

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end