Class: Google::Apis::RedisV1::PscServiceAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Configuration of a service attachment of the cluster, for creating PSC connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscServiceAttachment

Returns a new instance of PscServiceAttachment.



4087
4088
4089
# File 'lib/google/apis/redis_v1/classes.rb', line 4087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_typeString

Output only. Type of a PSC connection targeting this service attachment. Corresponds to the JSON property connectionType

Returns:

  • (String)


4079
4080
4081
# File 'lib/google/apis/redis_v1/classes.rb', line 4079

def connection_type
  @connection_type
end

#service_attachmentString

Output only. Service attachment URI which your self-created PscConnection should use as target Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


4085
4086
4087
# File 'lib/google/apis/redis_v1/classes.rb', line 4085

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4092
4093
4094
4095
# File 'lib/google/apis/redis_v1/classes.rb', line 4092

def update!(**args)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end