Class: Google::Apis::RedisV1::RemoteCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Details of the remote cluster associated with this cluster in a cross cluster replication setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteCluster

Returns a new instance of RemoteCluster.



3995
3996
3997
# File 'lib/google/apis/redis_v1/classes.rb', line 3995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Output only. The full resource path of the remote cluster in the format: projects//locations//clusters/ Corresponds to the JSON property cluster

Returns:

  • (String)


3988
3989
3990
# File 'lib/google/apis/redis_v1/classes.rb', line 3988

def cluster
  @cluster
end

#uidString

Output only. The unique identifier of the remote cluster. Corresponds to the JSON property uid

Returns:

  • (String)


3993
3994
3995
# File 'lib/google/apis/redis_v1/classes.rb', line 3993

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4000
4001
4002
4003
# File 'lib/google/apis/redis_v1/classes.rb', line 4000

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @uid = args[:uid] if args.key?(:uid)
end