Class: Google::Apis::RedisV1::TokenAuthUser
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::TokenAuthUser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Represents a token based auth user for the cluster.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TokenAuthUser
constructor
A new instance of TokenAuthUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TokenAuthUser
Returns a new instance of TokenAuthUser.
4531 4532 4533 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The resource name of the token based auth user. Format: projects/
project/locations/location/clusters/cluster/tokenAuthUsers/
token_auth_user
Corresponds to the JSON property name
4524 4525 4526 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4524 def name @name end |
#state ⇒ String
Output only. The state of the token based auth user.
Corresponds to the JSON property state
4529 4530 4531 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4529 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4536 4537 4538 4539 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4536 def update!(**args) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |