Class: Google::Apis::RedisV1::UserLabels
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::UserLabels
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
Corresponds to the JSON property
labels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserLabels
constructor
A new instance of UserLabels.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserLabels
Returns a new instance of UserLabels.
4669 4670 4671 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4669 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
Corresponds to the JSON property labels
4667 4668 4669 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4667 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4674 4675 4676 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4674 def update!(**args) @labels = args[:labels] if args.key?(:labels) end |