Class: Google::Apis::RedisV1::BackupDrMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::BackupDrMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::RedisV1::BackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::RedisV1::BackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::RedisV1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupDrMetadata
constructor
A new instance of BackupDrMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupDrMetadata
Returns a new instance of BackupDrMetadata.
574 575 576 |
# File 'lib/google/apis/redis_v1/classes.rb', line 574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::RedisV1::BackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
546 547 548 |
# File 'lib/google/apis/redis_v1/classes.rb', line 546 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::RedisV1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
551 552 553 |
# File 'lib/google/apis/redis_v1/classes.rb', line 551 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::RedisV1::BackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
557 558 559 |
# File 'lib/google/apis/redis_v1/classes.rb', line 557 def backupdr_configuration @backupdr_configuration end |
#full_resource_name ⇒ String
Required. Full resource name of this instance.
Corresponds to the JSON property fullResourceName
562 563 564 |
# File 'lib/google/apis/redis_v1/classes.rb', line 562 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time backup configuration was refreshed.
Corresponds to the JSON property lastRefreshTime
567 568 569 |
# File 'lib/google/apis/redis_v1/classes.rb', line 567 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
572 573 574 |
# File 'lib/google/apis/redis_v1/classes.rb', line 572 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
579 580 581 582 583 584 585 586 |
# File 'lib/google/apis/redis_v1/classes.rb', line 579 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) end |