Class: Google::Apis::RedisV1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
A cluster instance.
Instance Attribute Summary collapse
-
#acl_policy ⇒ String
Optional.
-
#acl_policy_in_sync ⇒ Boolean
(also: #acl_policy_in_sync?)
Optional.
-
#allow_fewer_zones_deployment ⇒ Boolean
(also: #allow_fewer_zones_deployment?)
Optional.
-
#async_cluster_endpoints_deletion_enabled ⇒ Boolean
(also: #async_cluster_endpoints_deletion_enabled?)
Optional.
-
#authorization_mode ⇒ String
Optional.
-
#automated_backup_config ⇒ Google::Apis::RedisV1::AutomatedBackupConfig
The automated backup config for a cluster.
-
#available_maintenance_versions ⇒ Array<String>
Output only.
-
#backup_collection ⇒ String
Optional.
-
#cluster_endpoints ⇒ Array<Google::Apis::RedisV1::ClusterEndpoint>
Optional.
-
#create_time ⇒ String
Output only.
-
#cross_cluster_replication_config ⇒ Google::Apis::RedisV1::CrossClusterReplicationConfig
Cross cluster replication config.
-
#deletion_protection_enabled ⇒ Boolean
(also: #deletion_protection_enabled?)
Optional.
-
#discovery_endpoints ⇒ Array<Google::Apis::RedisV1::DiscoveryEndpoint>
Output only.
-
#effective_maintenance_version ⇒ String
Output only.
-
#encryption_info ⇒ Google::Apis::RedisV1::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
-
#gcs_source ⇒ Google::Apis::RedisV1::GcsBackupSource
Backups stored in Cloud Storage buckets.
-
#kms_key ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#maintenance_policy ⇒ Google::Apis::RedisV1::ClusterMaintenancePolicy
Maintenance policy per cluster.
-
#maintenance_schedule ⇒ Google::Apis::RedisV1::ClusterMaintenanceSchedule
Upcoming maintenance schedule.
-
#maintenance_version ⇒ String
Optional.
-
#managed_backup_source ⇒ Google::Apis::RedisV1::ManagedBackupSource
Backups that generated and managed by memorystore.
-
#name ⇒ String
Required.
-
#node_type ⇒ String
Optional.
-
#ondemand_maintenance ⇒ Boolean
(also: #ondemand_maintenance?)
Optional.
-
#persistence_config ⇒ Google::Apis::RedisV1::ClusterPersistenceConfig
Configuration of the persistence functionality.
-
#precise_size_gb ⇒ Float
Output only.
-
#psc_configs ⇒ Array<Google::Apis::RedisV1::PscConfig>
Optional.
-
#psc_connections ⇒ Array<Google::Apis::RedisV1::PscConnection>
Output only.
-
#psc_service_attachments ⇒ Array<Google::Apis::RedisV1::PscServiceAttachment>
Output only.
-
#redis_configs ⇒ Hash<String,String>
Optional.
-
#replica_count ⇒ Fixnum
Optional.
-
#rotate_server_certificate ⇒ Boolean
(also: #rotate_server_certificate?)
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Optional.
-
#server_ca_mode ⇒ String
Optional.
-
#server_ca_pool ⇒ String
Optional.
-
#shard_count ⇒ Fixnum
Optional.
-
#simulate_maintenance_event ⇒ Boolean
(also: #simulate_maintenance_event?)
Optional.
-
#size_gb ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#state_info ⇒ Google::Apis::RedisV1::StateInfo
Represents additional information about the state of the cluster.
-
#transit_encryption_mode ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#zone_distribution_config ⇒ Google::Apis::RedisV1::ZoneDistributionConfig
Zone distribution config for allocation of cluster resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
966 967 968 |
# File 'lib/google/apis/redis_v1/classes.rb', line 966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_policy ⇒ String
Optional. The ACL policy to be applied to the cluster.
Corresponds to the JSON property aclPolicy
710 711 712 |
# File 'lib/google/apis/redis_v1/classes.rb', line 710 def acl_policy @acl_policy end |
#acl_policy_in_sync ⇒ Boolean Also known as: acl_policy_in_sync?
Optional. Output only. Indicates whether the ACL rules applied to the cluster
are in sync with the latest ACL policy rules. This field is only applicable if
the ACL policy is set for the cluster.
Corresponds to the JSON property aclPolicyInSync
717 718 719 |
# File 'lib/google/apis/redis_v1/classes.rb', line 717 def acl_policy_in_sync @acl_policy_in_sync end |
#allow_fewer_zones_deployment ⇒ Boolean Also known as: allow_fewer_zones_deployment?
Optional. Immutable. Deprecated, do not use.
Corresponds to the JSON property allowFewerZonesDeployment
723 724 725 |
# File 'lib/google/apis/redis_v1/classes.rb', line 723 def allow_fewer_zones_deployment @allow_fewer_zones_deployment end |
#async_cluster_endpoints_deletion_enabled ⇒ Boolean Also known as: async_cluster_endpoints_deletion_enabled?
Optional. If true, cluster endpoints that are created and registered by
customers can be deleted asynchronously. That is, such a cluster endpoint can
be de-registered before the forwarding rules in the cluster endpoint are
deleted.
Corresponds to the JSON property asyncClusterEndpointsDeletionEnabled
732 733 734 |
# File 'lib/google/apis/redis_v1/classes.rb', line 732 def async_cluster_endpoints_deletion_enabled @async_cluster_endpoints_deletion_enabled end |
#authorization_mode ⇒ String
Optional. The authorization mode of the Redis cluster. If not provided, auth
feature is disabled for the cluster.
Corresponds to the JSON property authorizationMode
739 740 741 |
# File 'lib/google/apis/redis_v1/classes.rb', line 739 def @authorization_mode end |
#automated_backup_config ⇒ Google::Apis::RedisV1::AutomatedBackupConfig
The automated backup config for a cluster.
Corresponds to the JSON property automatedBackupConfig
744 745 746 |
# File 'lib/google/apis/redis_v1/classes.rb', line 744 def automated_backup_config @automated_backup_config end |
#available_maintenance_versions ⇒ Array<String>
Output only. This field is used to determine the available maintenance
versions for the self service update.
Corresponds to the JSON property availableMaintenanceVersions
750 751 752 |
# File 'lib/google/apis/redis_v1/classes.rb', line 750 def available_maintenance_versions @available_maintenance_versions end |
#backup_collection ⇒ String
Optional. Output only. The backup collection full resource name. Example:
projects/project/locations/location/backupCollections/collection
Corresponds to the JSON property backupCollection
756 757 758 |
# File 'lib/google/apis/redis_v1/classes.rb', line 756 def backup_collection @backup_collection end |
#cluster_endpoints ⇒ Array<Google::Apis::RedisV1::ClusterEndpoint>
Optional. A list of cluster endpoints.
Corresponds to the JSON property clusterEndpoints
761 762 763 |
# File 'lib/google/apis/redis_v1/classes.rb', line 761 def cluster_endpoints @cluster_endpoints end |
#create_time ⇒ String
Output only. The timestamp associated with the cluster creation request.
Corresponds to the JSON property createTime
766 767 768 |
# File 'lib/google/apis/redis_v1/classes.rb', line 766 def create_time @create_time end |
#cross_cluster_replication_config ⇒ Google::Apis::RedisV1::CrossClusterReplicationConfig
Cross cluster replication config.
Corresponds to the JSON property crossClusterReplicationConfig
771 772 773 |
# File 'lib/google/apis/redis_v1/classes.rb', line 771 def cross_cluster_replication_config @cross_cluster_replication_config end |
#deletion_protection_enabled ⇒ Boolean Also known as: deletion_protection_enabled?
Optional. The delete operation will fail when the value is set to true.
Corresponds to the JSON property deletionProtectionEnabled
776 777 778 |
# File 'lib/google/apis/redis_v1/classes.rb', line 776 def deletion_protection_enabled @deletion_protection_enabled end |
#discovery_endpoints ⇒ Array<Google::Apis::RedisV1::DiscoveryEndpoint>
Output only. Endpoints created on each given network, for Redis clients to
connect to the cluster. Currently only one discovery endpoint is supported.
Corresponds to the JSON property discoveryEndpoints
783 784 785 |
# File 'lib/google/apis/redis_v1/classes.rb', line 783 def discovery_endpoints @discovery_endpoints end |
#effective_maintenance_version ⇒ String
Output only. This field represents the actual maintenance version of the
cluster.
Corresponds to the JSON property effectiveMaintenanceVersion
789 790 791 |
# File 'lib/google/apis/redis_v1/classes.rb', line 789 def effective_maintenance_version @effective_maintenance_version end |
#encryption_info ⇒ Google::Apis::RedisV1::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
Corresponds to the JSON property encryptionInfo
794 795 796 |
# File 'lib/google/apis/redis_v1/classes.rb', line 794 def encryption_info @encryption_info end |
#gcs_source ⇒ Google::Apis::RedisV1::GcsBackupSource
Backups stored in Cloud Storage buckets. The Cloud Storage buckets need to be
the same region as the clusters.
Corresponds to the JSON property gcsSource
800 801 802 |
# File 'lib/google/apis/redis_v1/classes.rb', line 800 def gcs_source @gcs_source end |
#kms_key ⇒ String
Optional. The KMS key used to encrypt the at-rest data of the cluster.
Corresponds to the JSON property kmsKey
805 806 807 |
# File 'lib/google/apis/redis_v1/classes.rb', line 805 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Optional. Labels to represent user-provided metadata.
Corresponds to the JSON property labels
810 811 812 |
# File 'lib/google/apis/redis_v1/classes.rb', line 810 def labels @labels end |
#maintenance_policy ⇒ Google::Apis::RedisV1::ClusterMaintenancePolicy
Maintenance policy per cluster.
Corresponds to the JSON property maintenancePolicy
815 816 817 |
# File 'lib/google/apis/redis_v1/classes.rb', line 815 def maintenance_policy @maintenance_policy end |
#maintenance_schedule ⇒ Google::Apis::RedisV1::ClusterMaintenanceSchedule
Upcoming maintenance schedule.
Corresponds to the JSON property maintenanceSchedule
820 821 822 |
# File 'lib/google/apis/redis_v1/classes.rb', line 820 def maintenance_schedule @maintenance_schedule end |
#maintenance_version ⇒ String
Optional. This field can be used to trigger self service update to indicate
the desired maintenance version. The input to this field can be determined by
the available_maintenance_versions field.
Corresponds to the JSON property maintenanceVersion
827 828 829 |
# File 'lib/google/apis/redis_v1/classes.rb', line 827 def maintenance_version @maintenance_version end |
#managed_backup_source ⇒ Google::Apis::RedisV1::ManagedBackupSource
Backups that generated and managed by memorystore.
Corresponds to the JSON property managedBackupSource
832 833 834 |
# File 'lib/google/apis/redis_v1/classes.rb', line 832 def managed_backup_source @managed_backup_source end |
#name ⇒ String
Required. Identifier. Unique name of the resource in this scope including
project and location using the form: projects/project_id/locations/
location_id/clusters/cluster_id`
Corresponds to the JSON propertyname`
839 840 841 |
# File 'lib/google/apis/redis_v1/classes.rb', line 839 def name @name end |
#node_type ⇒ String
Optional. The type of a redis node in the cluster. NodeType determines the
underlying machine-type of a redis node.
Corresponds to the JSON property nodeType
845 846 847 |
# File 'lib/google/apis/redis_v1/classes.rb', line 845 def node_type @node_type end |
#ondemand_maintenance ⇒ Boolean Also known as: ondemand_maintenance?
Optional. Input only. Ondemand maintenance for the cluster. This field can be
used to trigger ondemand critical update on the cluster.
Corresponds to the JSON property ondemandMaintenance
851 852 853 |
# File 'lib/google/apis/redis_v1/classes.rb', line 851 def ondemand_maintenance @ondemand_maintenance end |
#persistence_config ⇒ Google::Apis::RedisV1::ClusterPersistenceConfig
Configuration of the persistence functionality.
Corresponds to the JSON property persistenceConfig
857 858 859 |
# File 'lib/google/apis/redis_v1/classes.rb', line 857 def persistence_config @persistence_config end |
#precise_size_gb ⇒ Float
Output only. Precise value of redis memory size in GB for the entire cluster.
Corresponds to the JSON property preciseSizeGb
862 863 864 |
# File 'lib/google/apis/redis_v1/classes.rb', line 862 def precise_size_gb @precise_size_gb end |
#psc_configs ⇒ Array<Google::Apis::RedisV1::PscConfig>
Optional. Each PscConfig configures the consumer network where IPs will be
designated to the cluster for client access through Private Service Connect
Automation. Currently, only one PscConfig is supported.
Corresponds to the JSON property pscConfigs
869 870 871 |
# File 'lib/google/apis/redis_v1/classes.rb', line 869 def psc_configs @psc_configs end |
#psc_connections ⇒ Array<Google::Apis::RedisV1::PscConnection>
Output only. The list of PSC connections that are auto-created through service
connectivity automation.
Corresponds to the JSON property pscConnections
875 876 877 |
# File 'lib/google/apis/redis_v1/classes.rb', line 875 def psc_connections @psc_connections end |
#psc_service_attachments ⇒ Array<Google::Apis::RedisV1::PscServiceAttachment>
Output only. Service attachment details to configure Psc connections
Corresponds to the JSON property pscServiceAttachments
880 881 882 |
# File 'lib/google/apis/redis_v1/classes.rb', line 880 def @psc_service_attachments end |
#redis_configs ⇒ Hash<String,String>
Optional. Key/Value pairs of customer overrides for mutable Redis Configs
Corresponds to the JSON property redisConfigs
885 886 887 |
# File 'lib/google/apis/redis_v1/classes.rb', line 885 def redis_configs @redis_configs end |
#replica_count ⇒ Fixnum
Optional. The number of replica nodes per shard.
Corresponds to the JSON property replicaCount
890 891 892 |
# File 'lib/google/apis/redis_v1/classes.rb', line 890 def replica_count @replica_count end |
#rotate_server_certificate ⇒ Boolean Also known as: rotate_server_certificate?
Optional. Input only. Rotate the server certificates.
Corresponds to the JSON property rotateServerCertificate
895 896 897 |
# File 'lib/google/apis/redis_v1/classes.rb', line 895 def rotate_server_certificate @rotate_server_certificate end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
901 902 903 |
# File 'lib/google/apis/redis_v1/classes.rb', line 901 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
907 908 909 |
# File 'lib/google/apis/redis_v1/classes.rb', line 907 def satisfies_pzs @satisfies_pzs end |
#server_ca_mode ⇒ String
Optional. Server CA mode for the cluster.
Corresponds to the JSON property serverCaMode
913 914 915 |
# File 'lib/google/apis/redis_v1/classes.rb', line 913 def server_ca_mode @server_ca_mode end |
#server_ca_pool ⇒ String
Optional. Customer-managed CA pool for the cluster. Only applicable for BYOCA
i.e. if server_ca_mode is SERVER_CA_MODE_CUSTOMER_MANAGED_CAS_CA. Format: "
projects/project/locations/region/caPools/ca_pool".
Corresponds to the JSON property serverCaPool
920 921 922 |
# File 'lib/google/apis/redis_v1/classes.rb', line 920 def server_ca_pool @server_ca_pool end |
#shard_count ⇒ Fixnum
Optional. Number of shards for the Redis cluster.
Corresponds to the JSON property shardCount
925 926 927 |
# File 'lib/google/apis/redis_v1/classes.rb', line 925 def shard_count @shard_count end |
#simulate_maintenance_event ⇒ Boolean Also known as: simulate_maintenance_event?
Optional. Input only. Simulate a maintenance event.
Corresponds to the JSON property simulateMaintenanceEvent
930 931 932 |
# File 'lib/google/apis/redis_v1/classes.rb', line 930 def simulate_maintenance_event @simulate_maintenance_event end |
#size_gb ⇒ Fixnum
Output only. Redis memory size in GB for the entire cluster rounded up to the
next integer.
Corresponds to the JSON property sizeGb
937 938 939 |
# File 'lib/google/apis/redis_v1/classes.rb', line 937 def size_gb @size_gb end |
#state ⇒ String
Output only. The current state of this cluster. Can be CREATING, READY,
UPDATING, DELETING and SUSPENDED
Corresponds to the JSON property state
943 944 945 |
# File 'lib/google/apis/redis_v1/classes.rb', line 943 def state @state end |
#state_info ⇒ Google::Apis::RedisV1::StateInfo
Represents additional information about the state of the cluster.
Corresponds to the JSON property stateInfo
948 949 950 |
# File 'lib/google/apis/redis_v1/classes.rb', line 948 def state_info @state_info end |
#transit_encryption_mode ⇒ String
Optional. The in-transit encryption for the Redis cluster. If not provided,
encryption is disabled for the cluster.
Corresponds to the JSON property transitEncryptionMode
954 955 956 |
# File 'lib/google/apis/redis_v1/classes.rb', line 954 def transit_encryption_mode @transit_encryption_mode end |
#uid ⇒ String
Output only. System assigned, unique identifier for the cluster.
Corresponds to the JSON property uid
959 960 961 |
# File 'lib/google/apis/redis_v1/classes.rb', line 959 def uid @uid end |
#zone_distribution_config ⇒ Google::Apis::RedisV1::ZoneDistributionConfig
Zone distribution config for allocation of cluster resources.
Corresponds to the JSON property zoneDistributionConfig
964 965 966 |
# File 'lib/google/apis/redis_v1/classes.rb', line 964 def zone_distribution_config @zone_distribution_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/google/apis/redis_v1/classes.rb', line 971 def update!(**args) @acl_policy = args[:acl_policy] if args.key?(:acl_policy) @acl_policy_in_sync = args[:acl_policy_in_sync] if args.key?(:acl_policy_in_sync) @allow_fewer_zones_deployment = args[:allow_fewer_zones_deployment] if args.key?(:allow_fewer_zones_deployment) @async_cluster_endpoints_deletion_enabled = args[:async_cluster_endpoints_deletion_enabled] if args.key?(:async_cluster_endpoints_deletion_enabled) @authorization_mode = args[:authorization_mode] if args.key?(:authorization_mode) @automated_backup_config = args[:automated_backup_config] if args.key?(:automated_backup_config) @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions) @backup_collection = args[:backup_collection] if args.key?(:backup_collection) @cluster_endpoints = args[:cluster_endpoints] if args.key?(:cluster_endpoints) @create_time = args[:create_time] if args.key?(:create_time) @cross_cluster_replication_config = args[:cross_cluster_replication_config] if args.key?(:cross_cluster_replication_config) @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled) @discovery_endpoints = args[:discovery_endpoints] if args.key?(:discovery_endpoints) @effective_maintenance_version = args[:effective_maintenance_version] if args.key?(:effective_maintenance_version) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @managed_backup_source = args[:managed_backup_source] if args.key?(:managed_backup_source) @name = args[:name] if args.key?(:name) @node_type = args[:node_type] if args.key?(:node_type) @ondemand_maintenance = args[:ondemand_maintenance] if args.key?(:ondemand_maintenance) @persistence_config = args[:persistence_config] if args.key?(:persistence_config) @precise_size_gb = args[:precise_size_gb] if args.key?(:precise_size_gb) @psc_configs = args[:psc_configs] if args.key?(:psc_configs) @psc_connections = args[:psc_connections] if args.key?(:psc_connections) @psc_service_attachments = args[:psc_service_attachments] if args.key?(:psc_service_attachments) @redis_configs = args[:redis_configs] if args.key?(:redis_configs) @replica_count = args[:replica_count] if args.key?(:replica_count) @rotate_server_certificate = args[:rotate_server_certificate] if args.key?(:rotate_server_certificate) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @server_ca_mode = args[:server_ca_mode] if args.key?(:server_ca_mode) @server_ca_pool = args[:server_ca_pool] if args.key?(:server_ca_pool) @shard_count = args[:shard_count] if args.key?(:shard_count) @simulate_maintenance_event = args[:simulate_maintenance_event] if args.key?(:simulate_maintenance_event) @size_gb = args[:size_gb] if args.key?(:size_gb) @state = args[:state] if args.key?(:state) @state_info = args[:state_info] if args.key?(:state_info) @transit_encryption_mode = args[:transit_encryption_mode] if args.key?(:transit_encryption_mode) @uid = args[:uid] if args.key?(:uid) @zone_distribution_config = args[:zone_distribution_config] if args.key?(:zone_distribution_config) end |