Class: Google::Apis::RedisV1::ClusterWeeklyMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ClusterWeeklyMaintenanceWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Time window specified for weekly operations.
Instance Attribute Summary collapse
-
#day ⇒ String
Optional.
-
#start_time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterWeeklyMaintenanceWindow
constructor
A new instance of ClusterWeeklyMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterWeeklyMaintenanceWindow
Returns a new instance of ClusterWeeklyMaintenanceWindow.
987 988 989 |
# File 'lib/google/apis/redis_v1/classes.rb', line 987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Optional. Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
978 979 980 |
# File 'lib/google/apis/redis_v1/classes.rb', line 978 def day @day end |
#start_time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
985 986 987 |
# File 'lib/google/apis/redis_v1/classes.rb', line 985 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
992 993 994 995 |
# File 'lib/google/apis/redis_v1/classes.rb', line 992 def update!(**args) @day = args[:day] if args.key?(:day) @start_time = args[:start_time] if args.key?(:start_time) end |