Class: Google::Apis::RedisV1::DatabaseResourceFeed
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::DatabaseResourceFeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13
Instance Attribute Summary collapse
-
#backupdr_metadata ⇒ Google::Apis::RedisV1::BackupDrMetadata
BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.
-
#config_based_signal_data ⇒ Google::Apis::RedisV1::ConfigBasedSignalData
Config based signal data.
-
#database_resource_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceSignalData
Database resource signal data.
-
#feed_timestamp ⇒ String
Required.
-
#feed_type ⇒ String
Required.
-
#observability_metric_data ⇒ Google::Apis::RedisV1::ObservabilityMetricData
Corresponds to the JSON property
observabilityMetricData. -
#recommendation_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceRecommendationSignalData
Common model for database resource recommendation signal data.
-
#resource_health_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceHealthSignalData
Common model for database resource health signal data.
-
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#resource_metadata ⇒ Google::Apis::RedisV1::DatabaseResourceMetadata
Common model for database resource instance metadata.
-
#skip_ingestion ⇒ Boolean
(also: #skip_ingestion?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceFeed
constructor
A new instance of DatabaseResourceFeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceFeed
Returns a new instance of DatabaseResourceFeed.
1398 1399 1400 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backupdr_metadata ⇒ Google::Apis::RedisV1::BackupDrMetadata
BackupDRMetadata contains information about the backup and disaster recovery
metadata of a database resource.
Corresponds to the JSON property backupdrMetadata
1337 1338 1339 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1337 def @backupdr_metadata end |
#config_based_signal_data ⇒ Google::Apis::RedisV1::ConfigBasedSignalData
Config based signal data. This is used to send signals to Condor which are
based on the DB level configurations. These will be used to send signals for
self managed databases.
Corresponds to the JSON property configBasedSignalData
1344 1345 1346 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1344 def config_based_signal_data @config_based_signal_data end |
#database_resource_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceSignalData
Database resource signal data. This is used to send signals to Condor which
are based on the DB/Instance/Fleet level configurations. These will be used to
send signals for all inventory types. Next ID: 10
Corresponds to the JSON property databaseResourceSignalData
1351 1352 1353 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1351 def database_resource_signal_data @database_resource_signal_data end |
#feed_timestamp ⇒ String
Required. Timestamp when feed is generated.
Corresponds to the JSON property feedTimestamp
1356 1357 1358 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1356 def @feed_timestamp end |
#feed_type ⇒ String
Required. Type feed to be ingested into condor
Corresponds to the JSON property feedType
1361 1362 1363 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1361 def feed_type @feed_type end |
#observability_metric_data ⇒ Google::Apis::RedisV1::ObservabilityMetricData
Corresponds to the JSON property observabilityMetricData
1366 1367 1368 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1366 def observability_metric_data @observability_metric_data end |
#recommendation_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceRecommendationSignalData
Common model for database resource recommendation signal data.
Corresponds to the JSON property recommendationSignalData
1371 1372 1373 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1371 def recommendation_signal_data @recommendation_signal_data end |
#resource_health_signal_data ⇒ Google::Apis::RedisV1::DatabaseResourceHealthSignalData
Common model for database resource health signal data.
Corresponds to the JSON property resourceHealthSignalData
1376 1377 1378 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1376 def resource_health_signal_data @resource_health_signal_data end |
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
1381 1382 1383 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1381 def resource_id @resource_id end |
#resource_metadata ⇒ Google::Apis::RedisV1::DatabaseResourceMetadata
Common model for database resource instance metadata. Next ID: 32
Corresponds to the JSON property resourceMetadata
1386 1387 1388 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1386 def @resource_metadata end |
#skip_ingestion ⇒ Boolean Also known as: skip_ingestion?
Optional. If true, the feed won't be ingested by DB Center. This indicates
that the feed is intentionally skipped. For example, BackupDR feeds are only
needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB).
Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can
be skipped.
Corresponds to the JSON property skipIngestion
1395 1396 1397 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1395 def skip_ingestion @skip_ingestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1403 def update!(**args) @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata) @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data) @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data) @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp) @feed_type = args[:feed_type] if args.key?(:feed_type) @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data) @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data) @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata) @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion) end |