Class: Google::Apis::RedisV1::DatabaseResourceHealthSignalData
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::DatabaseResourceHealthSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Common model for database resource health signal data.
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata Corresponds to the JSON property
additionalMetadata. -
#compliance ⇒ Array<Google::Apis::RedisV1::Compliance>
Industry standards associated with this signal; if this signal is an issue, that could be a violation of the associated industry standard(s).
-
#description ⇒ String
Description associated with signal Corresponds to the JSON property
description. -
#event_time ⇒ String
Required.
-
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal can be obtained.
-
#location ⇒ String
This is used to identify the location of the resource.
-
#name ⇒ String
Required.
-
#provider ⇒ String
Cloud provider name.
-
#resource_container ⇒ String
Closest parent container of this resource.
-
#resource_name ⇒ String
Required.
-
#signal_class ⇒ String
Required.
-
#signal_id ⇒ String
Required.
-
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
-
#signal_type ⇒ String
Required.
-
#state ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceHealthSignalData
constructor
A new instance of DatabaseResourceHealthSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceHealthSignalData
Returns a new instance of DatabaseResourceHealthSignalData.
1510 1511 1512 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata
Corresponds to the JSON property additionalMetadata
1424 1425 1426 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1424 def @additional_metadata end |
#compliance ⇒ Array<Google::Apis::RedisV1::Compliance>
Industry standards associated with this signal; if this signal is an issue,
that could be a violation of the associated industry standard(s). For example,
AUTO_BACKUP_DISABLED signal is associated with CIS GCP 1.1, CIS GCP 1.2, CIS
GCP 1.3, NIST 800-53 and ISO-27001 compliance standards. If a database
resource does not have automated backup enable, it will violate these
following industry standards.
Corresponds to the JSON property compliance
1434 1435 1436 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1434 def compliance @compliance end |
#description ⇒ String
Description associated with signal
Corresponds to the JSON property description
1439 1440 1441 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1439 def description @description end |
#event_time ⇒ String
Required. The last time at which the event described by this signal took place
Corresponds to the JSON property eventTime
1444 1445 1446 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1444 def event_time @event_time end |
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal
can be obtained. In GCP, this will take user to SCC page to get more details
about signals.
Corresponds to the JSON property externalUri
1451 1452 1453 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1451 def external_uri @external_uri end |
#location ⇒ String
This is used to identify the location of the resource. Example: "us-central1"
Corresponds to the JSON property location
1456 1457 1458 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1456 def location @location end |
#name ⇒ String
Required. The name of the signal, ex: PUBLIC_SQL_INSTANCE,
SQL_LOG_ERROR_VERBOSITY etc.
Corresponds to the JSON property name
1462 1463 1464 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1462 def name @name end |
#provider ⇒ String
Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged
Corresponds to the JSON property provider
1467 1468 1469 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1467 def provider @provider end |
#resource_container ⇒ String
Closest parent container of this resource. In GCP, 'container' refers to a
Cloud Resource Manager project. It must be resource name of a Cloud Resource
Manager project with the format of "provider//", such as "projects/123". For
GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
1475 1476 1477 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1475 def resource_container @resource_container end |
#resource_name ⇒ String
Required. Database resource name associated with the signal. Resource name to
follow CAIS resource_name format as noted here go/condor-common-datamodel
Corresponds to the JSON property resourceName
1481 1482 1483 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1481 def resource_name @resource_name end |
#signal_class ⇒ String
Required. The class of the signal, such as if it's a THREAT or VULNERABILITY.
Corresponds to the JSON property signalClass
1486 1487 1488 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1486 def signal_class @signal_class end |
#signal_id ⇒ String
Required. Unique identifier for the signal. This is an unique id which would
be mainatined by partner to identify a signal.
Corresponds to the JSON property signalId
1492 1493 1494 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1492 def signal_id @signal_id end |
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
Corresponds to the JSON property signalSeverity
1497 1498 1499 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1497 def signal_severity @signal_severity end |
#signal_type ⇒ String
Required. Type of signal, for example, AVAILABLE_IN_MULTIPLE_ZONES,
LOGGING_MOST_ERRORS, etc.
Corresponds to the JSON property signalType
1503 1504 1505 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1503 def signal_type @signal_type end |
#state ⇒ String
Required. The state of the signal, such as if it's ACTIVE or RESOLVED.
Corresponds to the JSON property state
1508 1509 1510 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1508 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1515 def update!(**args) @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata) @compliance = args[:compliance] if args.key?(:compliance) @description = args[:description] if args.key?(:description) @event_time = args[:event_time] if args.key?(:event_time) @external_uri = args[:external_uri] if args.key?(:external_uri) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_name = args[:resource_name] if args.key?(:resource_name) @signal_class = args[:signal_class] if args.key?(:signal_class) @signal_id = args[:signal_id] if args.key?(:signal_id) @signal_severity = args[:signal_severity] if args.key?(:signal_severity) @signal_type = args[:signal_type] if args.key?(:signal_type) @state = args[:state] if args.key?(:state) end |