Class: Google::Apis::RedisV1::DatabaseResourceSignalData
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::DatabaseResourceSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10
Instance Attribute Summary collapse
-
#backup_run ⇒ Google::Apis::RedisV1::BackupRun
A backup run.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#location ⇒ String
Resource location.
-
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Deprecated: Use signal_metadata_list instead.
-
#signal_metadata_list ⇒ Array<Google::Apis::RedisV1::SignalMetadata>
This will support array of OneOf signal metadata information for a given signal type.
-
#signal_state ⇒ String
Required.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceSignalData
constructor
A new instance of DatabaseResourceSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceSignalData
Returns a new instance of DatabaseResourceSignalData.
1916 1917 1918 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_run ⇒ Google::Apis::RedisV1::BackupRun
A backup run.
Corresponds to the JSON property backupRun
1872 1873 1874 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1872 def backup_run @backup_run end |
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
1877 1878 1879 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1877 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
1882 1883 1884 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1882 def last_refresh_time @last_refresh_time end |
#location ⇒ String
Resource location.
Corresponds to the JSON property location
1887 1888 1889 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1887 def location @location end |
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
1892 1893 1894 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1892 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Deprecated: Use signal_metadata_list instead.
Corresponds to the JSON property signalBoolValue
1897 1898 1899 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1897 def signal_bool_value @signal_bool_value end |
#signal_metadata_list ⇒ Array<Google::Apis::RedisV1::SignalMetadata>
This will support array of OneOf signal metadata information for a given
signal type.
Corresponds to the JSON property signalMetadataList
1904 1905 1906 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1904 def @signal_metadata_list end |
#signal_state ⇒ String
Required. Output only. Signal state of the signal
Corresponds to the JSON property signalState
1909 1910 1911 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1909 def signal_state @signal_state end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
1914 1915 1916 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1914 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1921 def update!(**args) @backup_run = args[:backup_run] if args.key?(:backup_run) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @location = args[:location] if args.key?(:location) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list) @signal_state = args[:signal_state] if args.key?(:signal_state) @signal_type = args[:signal_type] if args.key?(:signal_type) end |