Class: Google::Apis::RedisV1::DatabaseResourceSignalData
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::DatabaseResourceSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 7
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Signal data for boolean signals.
-
#signal_state ⇒ String
Required.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResourceSignalData
constructor
A new instance of DatabaseResourceSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResourceSignalData
Returns a new instance of DatabaseResourceSignalData.
1730 1731 1732 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
1702 1703 1704 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1702 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
1707 1708 1709 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1707 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::RedisV1::DatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
1712 1713 1714 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1712 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Signal data for boolean signals.
Corresponds to the JSON property signalBoolValue
1717 1718 1719 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1717 def signal_bool_value @signal_bool_value end |
#signal_state ⇒ String
Required. Output only. Signal state of the signal
Corresponds to the JSON property signalState
1723 1724 1725 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1723 def signal_state @signal_state end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
1728 1729 1730 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1728 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'lib/google/apis/redis_v1/classes.rb', line 1735 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_state = args[:signal_state] if args.key?(:signal_state) @signal_type = args[:signal_type] if args.key?(:signal_type) end |