Class: Google::Apis::RedisV1::DiscoveryEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Endpoints on each network, for Redis clients to connect to the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryEndpoint

Returns a new instance of DiscoveryEndpoint.



1996
1997
1998
# File 'lib/google/apis/redis_v1/classes.rb', line 1996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. Address of the exposed Redis endpoint used by clients to connect to the service. The address could be either IP or hostname. Corresponds to the JSON property address

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/redis_v1/classes.rb', line 1983

def address
  @address
end

#portFixnum

Output only. The port number of the exposed Redis endpoint. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1988
1989
1990
# File 'lib/google/apis/redis_v1/classes.rb', line 1988

def port
  @port
end

#psc_configGoogle::Apis::RedisV1::PscConfig

Output only. Customer configuration for where the endpoint is created and accessed from. Corresponds to the JSON property pscConfig



1994
1995
1996
# File 'lib/google/apis/redis_v1/classes.rb', line 1994

def psc_config
  @psc_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2001
2002
2003
2004
2005
# File 'lib/google/apis/redis_v1/classes.rb', line 2001

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @port = args[:port] if args.key?(:port)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
end