Class: Google::Apis::RedisV1::DiscoveryEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Endpoints on each network, for Redis clients to connect to the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryEndpoint

Returns a new instance of DiscoveryEndpoint.



1807
1808
1809
# File 'lib/google/apis/redis_v1/classes.rb', line 1807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. Address of the exposed Redis endpoint used by clients to connect to the service. The address could be either IP or hostname. Corresponds to the JSON property address

Returns:

  • (String)


1794
1795
1796
# File 'lib/google/apis/redis_v1/classes.rb', line 1794

def address
  @address
end

#portFixnum

Output only. The port number of the exposed Redis endpoint. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1799
1800
1801
# File 'lib/google/apis/redis_v1/classes.rb', line 1799

def port
  @port
end

#psc_configGoogle::Apis::RedisV1::PscConfig

Output only. Customer configuration for where the endpoint is created and accessed from. Corresponds to the JSON property pscConfig



1805
1806
1807
# File 'lib/google/apis/redis_v1/classes.rb', line 1805

def psc_config
  @psc_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1812
1813
1814
1815
1816
# File 'lib/google/apis/redis_v1/classes.rb', line 1812

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @port = args[:port] if args.key?(:port)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
end