Class: Google::Apis::RedisV1::FixedFrequencySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

This schedule allows the backup to be triggered at a fixed frequency ( currently only daily is supported).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixedFrequencySchedule

Returns a new instance of FixedFrequencySchedule.



1969
1970
1971
# File 'lib/google/apis/redis_v1/classes.rb', line 1969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#start_timeGoogle::Apis::RedisV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1967
1968
1969
# File 'lib/google/apis/redis_v1/classes.rb', line 1967

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1974
1975
1976
# File 'lib/google/apis/redis_v1/classes.rb', line 1974

def update!(**args)
  @start_time = args[:start_time] if args.key?(:start_time)
end