Class: Google::Apis::RedisV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
A Memorystore for Redis instance.
Instance Attribute Summary collapse
-
#alternative_location_id ⇒ String
Optional.
-
#auth_enabled ⇒ Boolean
(also: #auth_enabled?)
Optional.
-
#authorized_network ⇒ String
Optional.
-
#available_maintenance_versions ⇒ Array<String>
Optional.
-
#connect_mode ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#current_location_id ⇒ String
Output only.
-
#customer_managed_key ⇒ String
Optional.
-
#display_name ⇒ String
An arbitrary and optional user-provided name for the instance.
-
#host ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata Corresponds to the JSON property
labels. -
#location_id ⇒ String
Optional.
-
#maintenance_policy ⇒ Google::Apis::RedisV1::MaintenancePolicy
Maintenance policy for an instance.
-
#maintenance_schedule ⇒ Google::Apis::RedisV1::MaintenanceSchedule
Upcoming maintenance schedule.
-
#maintenance_version ⇒ String
Optional.
-
#memory_size_gb ⇒ Fixnum
Required.
-
#name ⇒ String
Required.
-
#nodes ⇒ Array<Google::Apis::RedisV1::NodeInfo>
Output only.
-
#persistence_config ⇒ Google::Apis::RedisV1::PersistenceConfig
Configuration of the persistence functionality.
-
#persistence_iam_identity ⇒ String
Output only.
-
#port ⇒ Fixnum
Output only.
-
#read_endpoint ⇒ String
Output only.
-
#read_endpoint_port ⇒ Fixnum
Output only.
-
#read_replicas_mode ⇒ String
Optional.
-
#redis_configs ⇒ Hash<String,String>
Optional.
-
#redis_version ⇒ String
Optional.
-
#replica_count ⇒ Fixnum
Optional.
-
#reserved_ip_range ⇒ String
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Optional.
-
#secondary_ip_range ⇒ String
Optional.
-
#server_ca_certs ⇒ Array<Google::Apis::RedisV1::TlsCertificate>
Output only.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#suspension_reasons ⇒ Array<String>
Optional.
-
#tags ⇒ Hash<String,String>
Optional.
-
#tier ⇒ String
Required.
-
#transit_encryption_mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
2637 2638 2639 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternative_location_id ⇒ String
Optional. If specified, at least one node will be provisioned in this zone in
addition to the zone specified in location_id. Only applicable to standard
tier. If provided, it must be a different zone from the one provided in [
location_id]. Additional nodes beyond the first 2 will be placed in zones
selected by the service.
Corresponds to the JSON property alternativeLocationId
2391 2392 2393 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2391 def alternative_location_id @alternative_location_id end |
#auth_enabled ⇒ Boolean Also known as: auth_enabled?
Optional. Indicates whether OSS Redis AUTH is enabled for the instance. If set
to "true" AUTH is enabled on the instance. Default value is "false" meaning
AUTH is disabled.
Corresponds to the JSON property authEnabled
2398 2399 2400 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2398 def auth_enabled @auth_enabled end |
#authorized_network ⇒ String
Optional. The full name of the Google Compute Engine network to which the instance is connected. If left
unspecified, the default network will be used.
Corresponds to the JSON property authorizedNetwork
2406 2407 2408 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2406 def @authorized_network end |
#available_maintenance_versions ⇒ Array<String>
Optional. The available maintenance versions that an instance could update to.
Corresponds to the JSON property availableMaintenanceVersions
2411 2412 2413 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2411 def available_maintenance_versions @available_maintenance_versions end |
#connect_mode ⇒ String
Optional. The network connect mode of the Redis instance. If not provided, the
connect mode defaults to DIRECT_PEERING.
Corresponds to the JSON property connectMode
2417 2418 2419 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2417 def connect_mode @connect_mode end |
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
2422 2423 2424 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2422 def create_time @create_time end |
#current_location_id ⇒ String
Output only. The current zone where the Redis primary node is located. In
basic tier, this will always be the same as [location_id]. In standard tier,
this can be the zone of any node in the instance.
Corresponds to the JSON property currentLocationId
2429 2430 2431 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2429 def current_location_id @current_location_id end |
#customer_managed_key ⇒ String
Optional. The KMS key reference that the customer provides when trying to
create the instance.
Corresponds to the JSON property customerManagedKey
2435 2436 2437 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2435 def customer_managed_key @customer_managed_key end |
#display_name ⇒ String
An arbitrary and optional user-provided name for the instance.
Corresponds to the JSON property displayName
2440 2441 2442 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2440 def display_name @display_name end |
#host ⇒ String
Output only. Hostname or IP address of the exposed Redis endpoint used by
clients to connect to the service.
Corresponds to the JSON property host
2446 2447 2448 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2446 def host @host end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata
Corresponds to the JSON property labels
2451 2452 2453 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2451 def labels @labels end |
#location_id ⇒ String
Optional. The zone where the instance will be provisioned. If not provided,
the service will choose a zone from the specified region for the instance. For
standard tier, additional nodes will be added across multiple zones for
protection against zonal failures. If specified, at least one node will be
provisioned in this zone.
Corresponds to the JSON property locationId
2460 2461 2462 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2460 def location_id @location_id end |
#maintenance_policy ⇒ Google::Apis::RedisV1::MaintenancePolicy
Maintenance policy for an instance.
Corresponds to the JSON property maintenancePolicy
2465 2466 2467 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2465 def maintenance_policy @maintenance_policy end |
#maintenance_schedule ⇒ Google::Apis::RedisV1::MaintenanceSchedule
Upcoming maintenance schedule. If no maintenance is scheduled, fields are not
populated.
Corresponds to the JSON property maintenanceSchedule
2471 2472 2473 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2471 def maintenance_schedule @maintenance_schedule end |
#maintenance_version ⇒ String
Optional. The self service update maintenance version. The version is date
based such as "20210712_00_00".
Corresponds to the JSON property maintenanceVersion
2477 2478 2479 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2477 def maintenance_version @maintenance_version end |
#memory_size_gb ⇒ Fixnum
Required. Redis memory size in GiB.
Corresponds to the JSON property memorySizeGb
2482 2483 2484 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2482 def memory_size_gb @memory_size_gb end |
#name ⇒ String
Required. Unique name of the resource in this scope including project and
location using the form: projects/project_id/locations/location_id/
instances/instance_id`Note: Redis instances are managed and addressed at
regional level so location_id here refers to a GCP region; however, users may
choose which specific zone (or collection of zones for cross-zone instances)
an instance should be provisioned in. Refer to location_id and
alternative_location_id fields for more details.
Corresponds to the JSON propertyname`
2493 2494 2495 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2493 def name @name end |
#nodes ⇒ Array<Google::Apis::RedisV1::NodeInfo>
Output only. Info per node.
Corresponds to the JSON property nodes
2498 2499 2500 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2498 def nodes @nodes end |
#persistence_config ⇒ Google::Apis::RedisV1::PersistenceConfig
Configuration of the persistence functionality.
Corresponds to the JSON property persistenceConfig
2503 2504 2505 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2503 def persistence_config @persistence_config end |
#persistence_iam_identity ⇒ String
Output only. Cloud IAM identity used by import / export operations to transfer
data to/from Cloud Storage. Format is "serviceAccount:". The value may change
over time for a given instance so should be checked before each import/export
operation.
Corresponds to the JSON property persistenceIamIdentity
2511 2512 2513 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2511 def persistence_iam_identity @persistence_iam_identity end |
#port ⇒ Fixnum
Output only. The port number of the exposed Redis endpoint.
Corresponds to the JSON property port
2516 2517 2518 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2516 def port @port end |
#read_endpoint ⇒ String
Output only. Hostname or IP address of the exposed readonly Redis endpoint.
Standard tier only. Targets all healthy replica nodes in instance. Replication
is asynchronous and replica nodes will exhibit some lag behind the primary.
Write requests must target 'host'.
Corresponds to the JSON property readEndpoint
2524 2525 2526 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2524 def read_endpoint @read_endpoint end |
#read_endpoint_port ⇒ Fixnum
Output only. The port number of the exposed readonly redis endpoint. Standard
tier only. Write requests should target 'port'.
Corresponds to the JSON property readEndpointPort
2530 2531 2532 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2530 def read_endpoint_port @read_endpoint_port end |
#read_replicas_mode ⇒ String
Optional. Read replicas mode for the instance. Defaults to
READ_REPLICAS_DISABLED.
Corresponds to the JSON property readReplicasMode
2536 2537 2538 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2536 def read_replicas_mode @read_replicas_mode end |
#redis_configs ⇒ Hash<String,String>
Optional. Redis configuration parameters, according to Redis configuration.
Currently, the only supported parameters are: Redis version 3.2 and newer: *
maxmemory-policy * notify-keyspace-events Redis version 4.0 and newer: *
activedefrag * lfu-decay-time * lfu-log-factor * maxmemory-gb Redis version 5.
0 and newer: * stream-node-max-bytes * stream-node-max-entries
Corresponds to the JSON property redisConfigs
2546 2547 2548 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2546 def redis_configs @redis_configs end |
#redis_version ⇒ String
Optional. The version of Redis software. If not provided, the default version
will be used. Currently, the supported values are: * REDIS_3_2 for Redis 3.2
compatibility * REDIS_4_0 for Redis 4.0 compatibility * REDIS_5_0 for
Redis 5.0 compatibility * REDIS_6_X for Redis 6.x compatibility * REDIS_7_0
for Redis 7.0 compatibility (default) * REDIS_7_2 for Redis 7.2
compatibility
Corresponds to the JSON property redisVersion
2556 2557 2558 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2556 def redis_version @redis_version end |
#replica_count ⇒ Fixnum
Optional. The number of replica nodes. The valid range for the Standard Tier
with read replicas enabled is [1-5] and defaults to 2. If read replicas are
not enabled for a Standard Tier instance, the only valid value is 1 and the
default is 1. The valid value for basic tier is 0 and the default is also 0.
Corresponds to the JSON property replicaCount
2564 2565 2566 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2564 def replica_count @replica_count end |
#reserved_ip_range ⇒ String
Optional. For DIRECT_PEERING mode, the CIDR range of internal addresses that
are reserved for this instance. Range must be unique and non-overlapping with
existing subnets in an authorized network. For PRIVATE_SERVICE_ACCESS mode,
the name of one allocated IP address ranges associated with this private
service access connection. If not provided, the service will choose an unused /
29 block, for example, 10.0.0.0/29 or 192.168.0.0/29. For
READ_REPLICAS_ENABLED the default block size is /28.
Corresponds to the JSON property reservedIpRange
2575 2576 2577 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2575 def reserved_ip_range @reserved_ip_range end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2580 2581 2582 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2580 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2586 2587 2588 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2586 def satisfies_pzs @satisfies_pzs end |
#secondary_ip_range ⇒ String
Optional. Additional IP range for node placement. Required when enabling read
replicas on an existing instance. For DIRECT_PEERING mode value must be a CIDR
range of size /28, or "auto". For PRIVATE_SERVICE_ACCESS mode value must be
the name of an allocated address range associated with the private service
access connection, or "auto".
Corresponds to the JSON property secondaryIpRange
2596 2597 2598 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2596 def secondary_ip_range @secondary_ip_range end |
#server_ca_certs ⇒ Array<Google::Apis::RedisV1::TlsCertificate>
Output only. List of server CA certificates for the instance.
Corresponds to the JSON property serverCaCerts
2601 2602 2603 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2601 def server_ca_certs @server_ca_certs end |
#state ⇒ String
Output only. The current state of this instance.
Corresponds to the JSON property state
2606 2607 2608 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2606 def state @state end |
#status_message ⇒ String
Output only. Additional information about the current status of this instance,
if available.
Corresponds to the JSON property statusMessage
2612 2613 2614 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2612 def @status_message end |
#suspension_reasons ⇒ Array<String>
Optional. reasons that causes instance in "SUSPENDED" state.
Corresponds to the JSON property suspensionReasons
2617 2618 2619 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2617 def suspension_reasons @suspension_reasons end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
2624 2625 2626 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2624 def @tags end |
#tier ⇒ String
Required. The service tier of the instance.
Corresponds to the JSON property tier
2629 2630 2631 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2629 def tier @tier end |
#transit_encryption_mode ⇒ String
Optional. The TLS mode of the Redis instance. If not provided, TLS is disabled
for the instance.
Corresponds to the JSON property transitEncryptionMode
2635 2636 2637 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2635 def transit_encryption_mode @transit_encryption_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2642 def update!(**args) @alternative_location_id = args[:alternative_location_id] if args.key?(:alternative_location_id) @auth_enabled = args[:auth_enabled] if args.key?(:auth_enabled) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions) @connect_mode = args[:connect_mode] if args.key?(:connect_mode) @create_time = args[:create_time] if args.key?(:create_time) @current_location_id = args[:current_location_id] if args.key?(:current_location_id) @customer_managed_key = args[:customer_managed_key] if args.key?(:customer_managed_key) @display_name = args[:display_name] if args.key?(:display_name) @host = args[:host] if args.key?(:host) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb) @name = args[:name] if args.key?(:name) @nodes = args[:nodes] if args.key?(:nodes) @persistence_config = args[:persistence_config] if args.key?(:persistence_config) @persistence_iam_identity = args[:persistence_iam_identity] if args.key?(:persistence_iam_identity) @port = args[:port] if args.key?(:port) @read_endpoint = args[:read_endpoint] if args.key?(:read_endpoint) @read_endpoint_port = args[:read_endpoint_port] if args.key?(:read_endpoint_port) @read_replicas_mode = args[:read_replicas_mode] if args.key?(:read_replicas_mode) @redis_configs = args[:redis_configs] if args.key?(:redis_configs) @redis_version = args[:redis_version] if args.key?(:redis_version) @replica_count = args[:replica_count] if args.key?(:replica_count) @reserved_ip_range = args[:reserved_ip_range] if args.key?(:reserved_ip_range) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @secondary_ip_range = args[:secondary_ip_range] if args.key?(:secondary_ip_range) @server_ca_certs = args[:server_ca_certs] if args.key?(:server_ca_certs) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @suspension_reasons = args[:suspension_reasons] if args.key?(:suspension_reasons) @tags = args[:tags] if args.key?(:tags) @tier = args[:tier] if args.key?(:tier) @transit_encryption_mode = args[:transit_encryption_mode] if args.key?(:transit_encryption_mode) end |