Class: Google::Apis::RedisV1::InternalResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration settings. Similarly bigtable can have multiple clusters within same bigtable instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InternalResourceMetadata

Returns a new instance of InternalResourceMetadata.



2551
2552
2553
# File 'lib/google/apis/redis_v1/classes.rb', line 2551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::RedisV1::BackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



2522
2523
2524
# File 'lib/google/apis/redis_v1/classes.rb', line 2522

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::RedisV1::BackupRun

A backup run. Corresponds to the JSON property backupRun



2527
2528
2529
# File 'lib/google/apis/redis_v1/classes.rb', line 2527

def backup_run
  @backup_run
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Whether deletion protection is enabled for this internal resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


2532
2533
2534
# File 'lib/google/apis/redis_v1/classes.rb', line 2532

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#productGoogle::Apis::RedisV1::Product

Product specification for Condor resources. Corresponds to the JSON property product



2538
2539
2540
# File 'lib/google/apis/redis_v1/classes.rb', line 2538

def product
  @product
end

#resource_idGoogle::Apis::RedisV1::DatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



2543
2544
2545
# File 'lib/google/apis/redis_v1/classes.rb', line 2543

def resource_id
  @resource_id
end

#resource_nameString

Required. internal resource name for spanner this will be database name e.g." spanner.googleapis.com/projects/123/abc/instances/inst1/databases/db1" Corresponds to the JSON property resourceName

Returns:

  • (String)


2549
2550
2551
# File 'lib/google/apis/redis_v1/classes.rb', line 2549

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2556
2557
2558
2559
2560
2561
2562
2563
# File 'lib/google/apis/redis_v1/classes.rb', line 2556

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @product = args[:product] if args.key?(:product)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end