Class: Google::Apis::RedisV1::ListAclPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ListAclPoliciesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Response for ListAclPolicies.
Instance Attribute Summary collapse
-
#acl_policies ⇒ Array<Google::Apis::RedisV1::AclPolicy>
A list of ACL policies in the project in the specified location, or across all locations.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAclPoliciesResponse
constructor
A new instance of ListAclPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAclPoliciesResponse
Returns a new instance of ListAclPoliciesResponse.
2778 2779 2780 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_policies ⇒ Array<Google::Apis::RedisV1::AclPolicy>
A list of ACL policies in the project in the specified location, or across all
locations. If the location_id in the parent field of the request is "-", all
regions available to the project are queried, and the results aggregated.
Corresponds to the JSON property aclPolicies
2765 2766 2767 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2765 def acl_policies @acl_policies end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
2771 2772 2773 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2771 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2776 2777 2778 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2776 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2783 2784 2785 2786 2787 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2783 def update!(**args) @acl_policies = args[:acl_policies] if args.key?(:acl_policies) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |