Class: Google::Apis::RedisV1::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Response for ListBackups.
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::RedisV1::Backup>
A list of backups in the project.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Backups that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
2926 2927 2928 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::RedisV1::Backup>
A list of backups in the project.
Corresponds to the JSON property backups
2913 2914 2915 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2913 def backups @backups end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
2919 2920 2921 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2919 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Backups that could not be reached.
Corresponds to the JSON property unreachable
2924 2925 2926 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2924 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2931 2932 2933 2934 2935 |
# File 'lib/google/apis/redis_v1/classes.rb', line 2931 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |