Class: Google::Apis::RedisV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Response for ListBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



2927
2928
2929
# File 'lib/google/apis/redis_v1/classes.rb', line 2927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::RedisV1::Backup>

A list of backups in the project. Corresponds to the JSON property backups

Returns:



2914
2915
2916
# File 'lib/google/apis/redis_v1/classes.rb', line 2914

def backups
  @backups
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2920
2921
2922
# File 'lib/google/apis/redis_v1/classes.rb', line 2920

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Backups that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2925
2926
2927
# File 'lib/google/apis/redis_v1/classes.rb', line 2925

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2932
2933
2934
2935
2936
# File 'lib/google/apis/redis_v1/classes.rb', line 2932

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end