Class: Google::Apis::RedisV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Response for [ListBackups].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



2625
2626
2627
# File 'lib/google/apis/redis_v1/classes.rb', line 2625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::RedisV1::Backup>

A list of backups in the project. Corresponds to the JSON property backups

Returns:



2612
2613
2614
# File 'lib/google/apis/redis_v1/classes.rb', line 2612

def backups
  @backups
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2618
2619
2620
# File 'lib/google/apis/redis_v1/classes.rb', line 2618

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Backups that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2623
2624
2625
# File 'lib/google/apis/redis_v1/classes.rb', line 2623

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2630
2631
2632
2633
2634
# File 'lib/google/apis/redis_v1/classes.rb', line 2630

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end