Class: Google::Apis::RedisV1::ListTokenAuthUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ListTokenAuthUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Response message for ListTokenAuthUsers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#token_auth_users ⇒ Array<Google::Apis::RedisV1::TokenAuthUser>
A list of token auth users in the project.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTokenAuthUsersResponse
constructor
A new instance of ListTokenAuthUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTokenAuthUsersResponse
Returns a new instance of ListTokenAuthUsersResponse.
3050 3051 3052 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
3038 3039 3040 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3038 def next_page_token @next_page_token end |
#token_auth_users ⇒ Array<Google::Apis::RedisV1::TokenAuthUser>
A list of token auth users in the project.
Corresponds to the JSON property tokenAuthUsers
3043 3044 3045 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3043 def token_auth_users @token_auth_users end |
#unreachable ⇒ Array<String>
Unordered list. Token auth users that could not be reached.
Corresponds to the JSON property unreachable
3048 3049 3050 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3048 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3055 3056 3057 3058 3059 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3055 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @token_auth_users = args[:token_auth_users] if args.key?(:token_auth_users) @unreachable = args[:unreachable] if args.key?(:unreachable) end |