Class: Google::Apis::RedisV1::Location
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
Resource ID for the region.
-
#metadata ⇒ Hash<String,Object>
Output only.
-
#name ⇒ String
Full resource name for the region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
3142 3143 3144 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
3115 3116 3117 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3115 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
3121 3122 3123 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3121 def labels @labels end |
#location_id ⇒ String
Resource ID for the region. For example: "us-east1".
Corresponds to the JSON property locationId
3126 3127 3128 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3126 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Output only. The set of available zones in the location. The map is keyed by
the lowercase ID of each zone, as defined by Compute Engine. These keys can be
specified in location_id or alternative_location_id fields when creating a
Redis instance.
Corresponds to the JSON property metadata
3134 3135 3136 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3134 def @metadata end |
#name ⇒ String
Full resource name for the region. For example: "projects/example-project/
locations/us-east1".
Corresponds to the JSON property name
3140 3141 3142 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3140 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3147 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |