Class: Google::Apis::RedisV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



3097
3098
3099
# File 'lib/google/apis/redis_v1/classes.rb', line 3097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


3070
3071
3072
# File 'lib/google/apis/redis_v1/classes.rb', line 3070

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3076
3077
3078
# File 'lib/google/apis/redis_v1/classes.rb', line 3076

def labels
  @labels
end

#location_idString

Resource ID for the region. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


3081
3082
3083
# File 'lib/google/apis/redis_v1/classes.rb', line 3081

def location_id
  @location_id
end

#metadataHash<String,Object>

Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by Compute Engine. These keys can be specified in location_id or alternative_location_id fields when creating a Redis instance. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


3089
3090
3091
# File 'lib/google/apis/redis_v1/classes.rb', line 3089

def 
  @metadata
end

#nameString

Full resource name for the region. For example: "projects/example-project/ locations/us-east1". Corresponds to the JSON property name

Returns:

  • (String)


3095
3096
3097
# File 'lib/google/apis/redis_v1/classes.rb', line 3095

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3102
3103
3104
3105
3106
3107
3108
# File 'lib/google/apis/redis_v1/classes.rb', line 3102

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end