Class: Google::Apis::RedisV1::PscAutoConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscAutoConnection

Returns a new instance of PscAutoConnection.



3746
3747
3748
# File 'lib/google/apis/redis_v1/classes.rb', line 3746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. The IP allocated on the consumer network for the PSC forwarding rule. Corresponds to the JSON property address

Returns:

  • (String)


3702
3703
3704
# File 'lib/google/apis/redis_v1/classes.rb', line 3702

def address
  @address
end

#connection_typeString

Output only. Type of the PSC connection. Corresponds to the JSON property connectionType

Returns:

  • (String)


3707
3708
3709
# File 'lib/google/apis/redis_v1/classes.rb', line 3707

def connection_type
  @connection_type
end

#forwarding_ruleString

Output only. The URI of the consumer side forwarding rule. Example: projects/ projectNumOrId/regions/us-east1/forwardingRules/resourceId. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


3713
3714
3715
# File 'lib/google/apis/redis_v1/classes.rb', line 3713

def forwarding_rule
  @forwarding_rule
end

#networkString

Required. The consumer network where the IP address resides, in the form of projects/project_id/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


3719
3720
3721
# File 'lib/google/apis/redis_v1/classes.rb', line 3719

def network
  @network
end

#project_idString

Required. The consumer project_id where the forwarding rule is created from. Corresponds to the JSON property projectId

Returns:

  • (String)


3724
3725
3726
# File 'lib/google/apis/redis_v1/classes.rb', line 3724

def project_id
  @project_id
end

#psc_connection_idString

Output only. The PSC connection id of the forwarding rule connected to the service attachment. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/redis_v1/classes.rb', line 3730

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Output only. The status of the PSC connection. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status. Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


3737
3738
3739
# File 'lib/google/apis/redis_v1/classes.rb', line 3737

def psc_connection_status
  @psc_connection_status
end

#service_attachmentString

Output only. The service attachment which is the target of the PSC connection, in the form of projects/project-id/regions/region/serviceAttachments/ service-attachment-id. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


3744
3745
3746
# File 'lib/google/apis/redis_v1/classes.rb', line 3744

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
# File 'lib/google/apis/redis_v1/classes.rb', line 3751

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end