Class: Google::Apis::RedisV1::PscAutoConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscAutoConnection

Returns a new instance of PscAutoConnection.



3701
3702
3703
# File 'lib/google/apis/redis_v1/classes.rb', line 3701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. The IP allocated on the consumer network for the PSC forwarding rule. Corresponds to the JSON property address

Returns:

  • (String)


3657
3658
3659
# File 'lib/google/apis/redis_v1/classes.rb', line 3657

def address
  @address
end

#connection_typeString

Output only. Type of the PSC connection. Corresponds to the JSON property connectionType

Returns:

  • (String)


3662
3663
3664
# File 'lib/google/apis/redis_v1/classes.rb', line 3662

def connection_type
  @connection_type
end

#forwarding_ruleString

Output only. The URI of the consumer side forwarding rule. Example: projects/ projectNumOrId/regions/us-east1/forwardingRules/resourceId. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


3668
3669
3670
# File 'lib/google/apis/redis_v1/classes.rb', line 3668

def forwarding_rule
  @forwarding_rule
end

#networkString

Required. The consumer network where the IP address resides, in the form of projects/project_id/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


3674
3675
3676
# File 'lib/google/apis/redis_v1/classes.rb', line 3674

def network
  @network
end

#project_idString

Required. The consumer project_id where the forwarding rule is created from. Corresponds to the JSON property projectId

Returns:

  • (String)


3679
3680
3681
# File 'lib/google/apis/redis_v1/classes.rb', line 3679

def project_id
  @project_id
end

#psc_connection_idString

Output only. The PSC connection id of the forwarding rule connected to the service attachment. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


3685
3686
3687
# File 'lib/google/apis/redis_v1/classes.rb', line 3685

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Output only. The status of the PSC connection. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status. Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


3692
3693
3694
# File 'lib/google/apis/redis_v1/classes.rb', line 3692

def psc_connection_status
  @psc_connection_status
end

#service_attachmentString

Output only. The service attachment which is the target of the PSC connection, in the form of projects/project-id/regions/region/serviceAttachments/ service-attachment-id. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


3699
3700
3701
# File 'lib/google/apis/redis_v1/classes.rb', line 3699

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/google/apis/redis_v1/classes.rb', line 3706

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end