Class: Google::Apis::RedisV1::PscAutoConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscAutoConnection

Returns a new instance of PscAutoConnection.



3413
3414
3415
# File 'lib/google/apis/redis_v1/classes.rb', line 3413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. The IP allocated on the consumer network for the PSC forwarding rule. Corresponds to the JSON property address

Returns:

  • (String)


3369
3370
3371
# File 'lib/google/apis/redis_v1/classes.rb', line 3369

def address
  @address
end

#connection_typeString

Output only. Type of the PSC connection. Corresponds to the JSON property connectionType

Returns:

  • (String)


3374
3375
3376
# File 'lib/google/apis/redis_v1/classes.rb', line 3374

def connection_type
  @connection_type
end

#forwarding_ruleString

Output only. The URI of the consumer side forwarding rule. Example: projects/ projectNumOrId/regions/us-east1/forwardingRules/resourceId. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/redis_v1/classes.rb', line 3380

def forwarding_rule
  @forwarding_rule
end

#networkString

Required. The consumer network where the IP address resides, in the form of projects/project_id/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


3386
3387
3388
# File 'lib/google/apis/redis_v1/classes.rb', line 3386

def network
  @network
end

#project_idString

Required. The consumer project_id where the forwarding rule is created from. Corresponds to the JSON property projectId

Returns:

  • (String)


3391
3392
3393
# File 'lib/google/apis/redis_v1/classes.rb', line 3391

def project_id
  @project_id
end

#psc_connection_idString

Output only. The PSC connection id of the forwarding rule connected to the service attachment. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/redis_v1/classes.rb', line 3397

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Output only. The status of the PSC connection. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status. Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


3404
3405
3406
# File 'lib/google/apis/redis_v1/classes.rb', line 3404

def psc_connection_status
  @psc_connection_status
end

#service_attachmentString

Output only. The service attachment which is the target of the PSC connection, in the form of projects/project-id/regions/region/serviceAttachments/ service-attachment-id. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


3411
3412
3413
# File 'lib/google/apis/redis_v1/classes.rb', line 3411

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
# File 'lib/google/apis/redis_v1/classes.rb', line 3418

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end