Class: Google::Apis::RedisV1::ResourceMaintenanceDenySchedule
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ResourceMaintenanceDenySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Deny maintenance period for the database resource. It specifies the time range during which the maintenance cannot start. This is configured by the customer.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::RedisV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::RedisV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
constructor
A new instance of ResourceMaintenanceDenySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
Returns a new instance of ResourceMaintenanceDenySchedule.
3789 3790 3791 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::RedisV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
3768 3769 3770 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3768 def end_date @end_date end |
#start_date ⇒ Google::Apis::RedisV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
3780 3781 3782 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3780 def start_date @start_date end |
#time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
3787 3788 3789 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3787 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3794 3795 3796 3797 3798 |
# File 'lib/google/apis/redis_v1/classes.rb', line 3794 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |