Class: Google::Apis::RedisV1::ResourceMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::RedisV1::ResourceMaintenanceSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb
Overview
Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer.
Instance Attribute Summary collapse
-
#day ⇒ String
Optional.
-
#phase ⇒ String
Optional.
-
#time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceSchedule
constructor
A new instance of ResourceMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceSchedule
Returns a new instance of ResourceMaintenanceSchedule.
4185 4186 4187 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.
Corresponds to the JSON property day
4167 4168 4169 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4167 def day @day end |
#phase ⇒ String
Optional. Phase of the maintenance window. This is to capture order of
maintenance. For example, for Cloud SQL resources, this can be used to capture
if the maintenance window is in Week1, Week2, Week5, etc. Non production
resources are usually part of early phase. For more details, refer to Cloud
SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance
Corresponds to the JSON property phase
4176 4177 4178 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4176 def phase @phase end |
#time ⇒ Google::Apis::RedisV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
4183 4184 4185 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4183 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4190 4191 4192 4193 4194 |
# File 'lib/google/apis/redis_v1/classes.rb', line 4190 def update!(**args) @day = args[:day] if args.key?(:day) @phase = args[:phase] if args.key?(:phase) @time = args[:time] if args.key?(:time) end |