Class: Google::Apis::RedisV1::TokenAuthUser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/redis_v1/classes.rb,
lib/google/apis/redis_v1/representations.rb,
lib/google/apis/redis_v1/representations.rb

Overview

Represents a token based auth user for the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TokenAuthUser

Returns a new instance of TokenAuthUser.



4480
4481
4482
# File 'lib/google/apis/redis_v1/classes.rb', line 4480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the token based auth user. Format: projects/ project/locations/location/clusters/cluster/tokenAuthUsers/ token_auth_user Corresponds to the JSON property name

Returns:

  • (String)


4473
4474
4475
# File 'lib/google/apis/redis_v1/classes.rb', line 4473

def name
  @name
end

#stateString

Output only. The state of the token based auth user. Corresponds to the JSON property state

Returns:

  • (String)


4478
4479
4480
# File 'lib/google/apis/redis_v1/classes.rb', line 4478

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4485
4486
4487
4488
# File 'lib/google/apis/redis_v1/classes.rb', line 4485

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end